<?php

return [

    'title' => 'កំណត់ពាក្យសម្ងាត់របស់អ្នកឡើងវិញ',

    'heading' => 'ភ្លេចពាក្យសម្ងាត់របស់អ្នក?',

    'actions' => [

        'login' => [
            'label' => 'ត្រលប់ទៅការចូលប្រើប្រាស់',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'អាស័យដ្ធានអ៊ីម៉ែល',
        ],

        'actions' => [

            'request' => [
                'label' => 'ផ្ញើអ៊ីមែល',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'សំណើច្រើនពេក',
            'body' => 'សូមព្យាយាមម្តងទៀតក្នុងរយៈពេល :seconds វិនាទី។.',
        ],

    ],

];
