<?php

return [

    'title' => 'Menetapkan semula kata laluan anda',

    'heading' => 'Lupa kata laluan?',

    'actions' => [

        'login' => [
            'label' => 'kembali untuk log masuk',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'Alamat emel',
        ],

        'actions' => [

            'request' => [
                'label' => 'Hantar emel',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'Terlalu banyak permintaan',
            'body' => 'Sila cuba lagi dalam :second saat.',
        ],

    ],

];
