<?php

return [

    'title' => 'आफ्नो इमेल ठेगाना प्रमाणित गर्नुहोस्',

    'heading' => 'आफ्नो इमेल ठेगाना प्रमाणित गर्नुहोस्',

    'actions' => [

        'resend_notification' => [
            'label' => 'यसलाई फेरी पठाउनुहोस्',
        ],

    ],

    'messages' => [
        'notification_not_received' => 'हामीले पठाएको इमेल प्राप्त भएन?',
        'notification_sent' => 'हामीले तपाईको इमेल ठेगाना कसरी प्रमाणित गर्ने भन्ने बारे निर्देशनहरू सहित :email मा इमेल पठाएका छौं।',
    ],

    'notifications' => [

        'notification_resent' => [
            'title' => 'हामीले इमेल पुन पठाएका छौं।',
        ],

        'notification_resend_throttled' => [
            'title' => 'धेरै धेरै पुन पठाउने प्रयासहरू',
            'body' => 'कृपया :seconds सेकेन्डमा पुन प्रयास गर्नुहोस्।',
        ],

    ],

];
