<?php

return [

    'title' => 'Подтвердите свой адрес электронной почты',

    'heading' => 'Подтвердите свой адрес электронной почты',

    'actions' => [

        'resend_notification' => [
            'label' => 'Отправить еще раз',
        ],

    ],

    'messages' => [
        'notification_not_received' => 'Не получили письмо, которое мы отправили?',
        'notification_sent' => 'Мы отправили электронное письмо на адрес :email, содержащее инструкции о том, как подтвердить свой адрес электронной почты.',
    ],

    'notifications' => [

        'notification_resent' => [
            'title' => 'Мы повторно отправили электронное письмо.',
        ],

        'notification_resend_throttled' => [
            'title' => 'Слишком много попыток повторной отправки',
            'body' => 'Пожалуйста, попробуйте еще раз через :seconds секунд.',
        ],

    ],

];
