<?php

return [

    'direction' => 'rtl',

    'actions' => [

        'billing' => [
            'label' => 'مدیریت آبونمان',
        ],

        'logout' => [
            'label' => 'خروج',
        ],

        'open_database_notifications' => [
            'label' => 'نمایش اعلانات',
        ],

        'open_user_menu' => [
            'label' => 'منوی کاربر',
        ],

        'sidebar' => [

            'collapse' => [
                'label' => 'بستن نوار کناری',
            ],

            'expand' => [
                'label' => 'باز کردن نوار کناری',
            ],

        ],

        'theme_switcher' => [

            'dark' => [
                'label' => 'حالت تیره',
            ],

            'light' => [
                'label' => 'حالت روشن',
            ],

            'system' => [
                'label' => 'حالت سیستم',
            ],

        ],

    ],

];
