<?php

return [

    'single' => [

        'label' => 'Detașare',

        'modal' => [

            'heading' => 'Detașare :label',

            'actions' => [

                'detach' => [
                    'label' => 'Detașare',
                ],

            ],

        ],

        'notifications' => [

            'detached' => [
                'title' => 'Detașat cu succes',
            ],

        ],

    ],

    'multiple' => [

        'label' => 'Detașați înregistrările selectate',

        'modal' => [

            'heading' => 'Detașați :label selectate',

            'actions' => [

                'detach' => [
                    'label' => 'Detașați înregistrările selectate',
                ],

            ],

        ],

        'notifications' => [

            'detached' => [
                'title' => 'Detașat cu succes',
            ],

        ],

    ],

];
