<?php

return [

    'title' => '建立 :label',

    'breadcrumb' => '建立',

    'form' => [

        'actions' => [

            'cancel' => [
                'label' => '取消',
            ],

            'create' => [
                'label' => '建立',
            ],

            'create_another' => [
                'label' => '建立後再建立另一個',
            ],

        ],

    ],

    'notifications' => [

        'created' => [
            'title' => '已建立',
        ],

    ],

];
