<?php

return [

    'direction' => 'ltr',

    'actions' => [

        'billing' => [
            'label' => 'Upravljanje naročnine',
        ],

        'logout' => [
            'label' => 'Odjava',
        ],

        'open_database_notifications' => [
            'label' => 'Odpri obvestila',
        ],

        'open_user_menu' => [
            'label' => 'Uporabniški meni',
        ],

        'sidebar' => [

            'collapse' => [
                'label' => 'Strni stranski meni',
            ],

            'expand' => [
                'label' => 'Razširi stranski meni',
            ],

        ],

        'theme_switcher' => [

            'dark' => [
                'label' => 'Omogoči temno temo',
            ],

            'light' => [
                'label' => 'Omogoči svetlo temo',
            ],

            'system' => [
                'label' => 'Omogoči sistemsko temo',
            ],

        ],

    ],

    'avatar' => [
        'alt' => 'Avatar uporabnika :name',
    ],

    'logo' => [
        'alt' => 'Logotip :name',
    ],

];
