<?php

return [

    'title' => 'אפס את הסיסמה שלך',

    'heading' => 'שכחת את הסיסמה שלך?',

    'actions' => [

        'login' => [
            'label' => 'חזרה להתחברות',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'כתובת דוא"ל',
        ],

        'actions' => [

            'request' => [
                'label' => 'שלח אימייל',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'יותר מדי בקשות',
            'body' => 'נסה שוב בעוד :seconds שניות',
        ],

    ],

];
