<?php

return [

    'confirmation' => 'Sind Sie sicher, dass Sie dies tun möchten?',

    'actions' => [

        'cancel' => [
            'label' => 'Abbrechen',
        ],

        'confirm' => [
            'label' => 'Bestätigen',
        ],

        'submit' => [
            'label' => 'Absenden',
        ],

    ],

];
