<?php

return [

    'title' => 'E-poçt ünvanınızı təsdiqləyin',

    'heading' => 'E-poçt ünvanınızı təsdiqləyin',

    'actions' => [

        'resend_notification' => [
            'label' => 'Yenidən Göndər',
        ],

    ],

    'messages' => [
        'notification_not_received' => 'Göndərdiyimiz e-poçt gəlmədi?',
        'notification_sent' => ':email ünvanına, daxilində e-poçt ünvanınızı necə təsdiqləyəcəyiniz barədə təlimatlar olan bir e-poçt göndərdik.',
    ],

    'notifications' => [

        'notification_resent' => [
            'title' => 'E-poçt yenidən göndərildi.',
        ],

        'notification_resend_throttled' => [
            'title' => 'Bir çox yenidən göndərmə cəhdi',
            'body' => 'Zəhmət olmazsa :seconds saniyə sonra təkrar yoxlayın.',
        ],

    ],

];
