<?php

return [

    'builder' => [

        'actions' => [

            'clone' => [
                'label' => 'Clôn',
            ],

            'add' => [
                'label' => 'Ychwanegu at :label',
            ],

            'add_between' => [
                'label' => 'Mewnosod',
            ],

            'delete' => [
                'label' => 'Dileu',
            ],

            'reorder' => [
                'label' => 'Symud',
            ],

            'move_down' => [
                'label' => 'Symud i lawr',
            ],

            'move_up' => [
                'label' => 'Symud i fyny',
            ],

            'collapse' => [
                'label' => 'Cwympo',
            ],

            'expand' => [
                'label' => 'Ymledu',
            ],

            'collapse_all' => [
                'label' => 'Cwympo popeth',
            ],

            'expand_all' => [
                'label' => 'Ymledu popeth',
            ],

        ],

    ],

    'checkbox_list' => [

        'actions' => [

            'deselect_all' => [
                'label' => 'Dad ddewis popeth',
            ],

            'select_all' => [
                'label' => 'Dewis popeth',
            ],

        ],

    ],

    'key_value' => [

        'actions' => [

            'add' => [
                'label' => 'Ychwanegu rhes',
            ],

            'delete' => [
                'label' => 'Dileu rhes',
            ],

            'reorder' => [
                'label' => 'Rhes recordiwr',
            ],

        ],

        'fields' => [

            'key' => [
                'label' => 'Allwedd',
            ],

            'value' => [
                'label' => 'Gwerth',
            ],

        ],

    ],

    'markdown_editor' => [

        'toolbar_buttons' => [
            'attach_files' => 'Atodi ffeiliau',
            'bold' => 'Trwm',
            'bullet_list' => 'Rhestr bwled',
            'code_block' => 'Bloc côd',
            'edit' => 'Golygu',
            'italic' => 'Italig',
            'link' => 'Dolen',
            'ordered_list' => 'Rhestr wedi i rhifo',
            'preview' => 'Rhagolwg',
            'strike' => 'Llinell drwodd',
        ],

    ],

    'repeater' => [

        'actions' => [

            'add' => [
                'label' => 'Ychwanegu at :label',
            ],

            'delete' => [
                'label' => 'Dileu',
            ],

            'clone' => [
                'label' => 'Clôn',
            ],

            'reorder' => [
                'label' => 'Symud',
            ],

            'move_down' => [
                'label' => 'Symud i lawr',
            ],

            'move_up' => [
                'label' => 'Symud i fyny',
            ],

            'collapse' => [
                'label' => 'Cwympo',
            ],

            'expand' => [
                'label' => 'Ymledu',
            ],

            'collapse_all' => [
                'label' => 'Cwympo popeth',
            ],

            'expand_all' => [
                'label' => 'Ymledu popeth',
            ],

        ],

    ],

    'rich_editor' => [

        'dialogs' => [

            'link' => [

                'actions' => [
                    'link' => 'Dolen',
                    'unlink' => 'Datgysylltu',
                ],

                'label' => 'URL',

                'placeholder' => 'Rhowch URL',

            ],

        ],

        'toolbar_buttons' => [
            'attach_files' => 'Atodi ffeiliau',
            'blockquote' => 'Dyfynnod Bloc',
            'bold' => 'Trwm',
            'bullet_list' => 'Rhestr bwled',
            'code_block' => 'Bloc côd',
            'h1' => 'Teitl',
            'h2' => 'Pennawd',
            'h3' => 'Is-bennawd',
            'italic' => 'Italig',
            'link' => 'Dolen',
            'ordered_list' => 'Rhestr wedi`i rhifo',
            'redo' => 'Ail-wneud',
            'strike' => 'Llinell drwodd',
            'undo' => 'Dadwneud',
        ],

    ],

    'select' => [

        'actions' => [

            'create_option' => [

                'modal' => [

                    'heading' => 'Creu',

                    'actions' => [

                        'create' => [
                            'label' => 'Creu',
                        ],

                    ],

                ],

            ],

        ],

        'boolean' => [
            'true' => 'Ie',
            'false' => 'Na',
        ],

        'loading_message' => 'Llwytho...',

        'max_items_message' => 'Gall dim on :count gael eu dewis.',

        'no_search_results_message' => 'Nid oes unrhyw opsiynau yn cyfateb i`ch chwiliad.',

        'placeholder' => 'Dewis opsiwn',

        'searching_message' => 'Chwilio...',

        'search_prompt' => 'Dechrau teipio i chwilio...',

    ],

    'tags_input' => [
        'placeholder' => 'Tag newydd',
    ],

    'wizard' => [

        'actions' => [

            'previous_step' => [
                'label' => 'Yn ôl',
            ],

            'next_step' => [
                'label' => 'Nesaf',
            ],

        ],

    ],

];
