<?php

return [

    'title' => 'Atur ulang kata sandi',

    'heading' => 'Lupa kata sandi?',

    'actions' => [

        'login' => [
            'label' => 'Kembali ke halaman masuk',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'Alamat email',
        ],

        'actions' => [

            'request' => [
                'label' => 'Kirim email',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'Terlalu banyak permintaan',
            'body' => 'Silakan coba lagi dalam :seconds detik.',
        ],

    ],

];
