<?php

return [

    'direction' => 'ltr',

    'actions' => [

        'billing' => [
            'label' => 'Управление на плащания',
        ],

        'logout' => [
            'label' => 'Изход',
        ],

        'open_database_notifications' => [
            'label' => 'Известия',
        ],

        'open_user_menu' => [
            'label' => 'Потребителско меню',
        ],

        'sidebar' => [

            'collapse' => [
                'label' => 'Свий страничната лента',
            ],

            'expand' => [
                'label' => 'Разшири страничната лента',
            ],

        ],

        'theme_switcher' => [

            'dark' => [
                'label' => 'Включи тъмна тема',
            ],

            'light' => [
                'label' => 'Включи светла тема',
            ],

            'system' => [
                'label' => 'Включи системна тема',
            ],

        ],

    ],

];
