<?php

return [

    'builder' => [

        'actions' => [

            'clone' => [
                'label' => 'অনুলিপি করুন',
            ],

            'add' => [
                'label' => ':label এ যোগ করুন',
            ],

            'add_between' => [
                'label' => 'প্রবেশ করান',
            ],

            'delete' => [
                'label' => 'মুছে ফেলুন',
            ],

            'reorder' => [
                'label' => 'সরান',
            ],

            'move_down' => [
                'label' => 'নিচে সরান',
            ],

            'move_up' => [
                'label' => 'উপরে সরান',
            ],

            'collapse' => [
                'label' => 'ছোট করুন',
            ],

            'expand' => [
                'label' => 'বড় করুন',
            ],

            'collapse_all' => [
                'label' => 'সব ছোট করুন',
            ],

            'expand_all' => [
                'label' => 'সব বড় করুন',
            ],

        ],

    ],

    'checkbox_list' => [

        'actions' => [

            'select_all' => [
                'label' => 'সব নির্বাচিত করুন',
            ],

            'deselect_all' => [
                'label' => 'সব অনির্বাচিত করুন',
            ],

        ],

    ],

    'key_value' => [

        'actions' => [

            'add' => [
                'label' => 'সারি যোগ করুন',
            ],

            'delete' => [
                'label' => 'সারি মুছে ফেলুন',
            ],

            'reorder' => [
                'label' => 'সারি পুনর্বিন্যাস করুন',
            ],

        ],

        'fields' => [

            'key' => [
                'label' => 'চাবি',
            ],

            'value' => [
                'label' => 'মান',
            ],

        ],

    ],

    'markdown_editor' => [

        'toolbar_buttons' => [
            'attach_files' => 'নথি যোগ করুন',
            'bold' => 'বোল্ড',
            'bullet_list' => 'বুলেট তালিকা',
            'code_block' => 'কোড ব্লক',
            'edit' => 'সম্পাদন',
            'italic' => 'তির্যক',
            'link' => 'লিংক',
            'ordered_list' => 'সংখ্যাযুক্ত তালিকা',
            'preview' => 'পূর্বরূপ',
            'strike' => 'স্ট্রাইকথ্রু',
        ],

    ],

    'repeater' => [

        'actions' => [

            'add' => [
                'label' => ':label এ যোগ করুন',
            ],

            'delete' => [
                'label' => 'মুছে ফেলুন',
            ],

            'clone' => [
                'label' => 'অনুলিপি করুন',
            ],

            'reorder' => [
                'label' => 'সরান',
            ],

            'move_down' => [
                'label' => 'নিচে সরান',
            ],

            'move_up' => [
                'label' => 'উপরে সরান',
            ],

            'collapse' => [
                'label' => 'ছোট করুন',
            ],

            'expand' => [
                'label' => 'বড় করুন',
            ],

            'collapse_all' => [
                'label' => 'সব ছোট করুন',
            ],

            'expand_all' => [
                'label' => 'সব বড় করুন',
            ],

        ],

    ],

    'rich_editor' => [

        'dialogs' => [

            'link' => [

                'actions' => [
                    'link' => 'লিংক',
                    'unlink' => 'আনলিংক',
                ],

                'label' => 'ইউআরএল',

                'placeholder' => 'ইউআরএল দিন',

            ],

        ],

        'toolbar_buttons' => [
            'attach_files' => 'নথি যোগ করুন',
            'blockquote' => 'ব্লককোট',
            'bold' => 'বোল্ড',
            'bullet_list' => 'বুলেট তালিকা',
            'code_block' => 'কোড ব্লক',
            'h1' => 'শিরোনাম',
            'h2' => 'শিরোনাম',
            'h3' => 'উপশিরোনাম',
            'italic' => 'তির্যক',
            'link' => 'লিংক',
            'ordered_list' => 'সংখ্যাযুক্ত তালিকা',
            'redo' => 'পরবর্তী',
            'strike' => 'স্ট্রাইকথ্রু',
            'undo' => 'পূর্বাবস্থা',
        ],

    ],

    'select' => [

        'actions' => [

            'create_option' => [

                'modal' => [

                    'heading' => 'তৈরী করুন',

                    'actions' => [

                        'create' => [
                            'label' => 'তৈরী করুন',
                        ],

                    ],

                ],

            ],

        ],

        'boolean' => [
            'true' => 'হ্যাঁ',
            'false' => 'না',
        ],

        'loading_message' => 'লোড হচ্ছে...',

        'max_items_message' => 'মাত্র :count টা নির্বাচন করা যাবে।',

        'no_search_results_message' => 'খুঁজে পাওয়া যায় নি।',

        'placeholder' => 'নির্বাচন করুন',

        'searching_message' => 'খুঁজুন...',

        'search_prompt' => 'লিখুন...',

    ],

    'tags_input' => [
        'placeholder' => 'নতুন ট্যাগ',
    ],

    'wizard' => [

        'actions' => [

            'previous_step' => [
                'label' => 'পেছনে',
            ],

            'next_step' => [
                'label' => 'পরবর্তী',
            ],

        ],

    ],

];
