<?php

return [

    'title' => 'დაადასტურეთ თქვენი ელფოსტა',

    'heading' => 'დაადასტურეთ თქვენი ელფოსტა',

    'actions' => [

        'resend_notification' => [
            'label' => 'ხელახლა გაგზავნა',
        ],

    ],

    'messages' => [
        'notification_not_received' => 'არ მიგიღიათ ჩვენ მიერ გამოგზავნილი ელფოსტა?',
        'notification_sent' => 'ჩვენ გამოვაგზავნეთ ელფოსტა მისამართზე :email, რომელშიც აღწერილია ელფოსტის ვერიფიცირების ინსტრუქცია.',
    ],

    'notifications' => [

        'notification_resent' => [
            'title' => 'ჩვენ ხელახლა გავგზავნეთ ელფოსტა.',
        ],

        'notification_resend_throttled' => [
            'title' => 'ზედმეტად ბევრი ხელახლა გაგზავნის მცდელობა',
            'body' => 'გთხოვთ სცადეთ კიდევ :seconds წამში.',
        ],

    ],

];
