<?php

return [

    'confirmation' => 'Biztos, hogy ezt akarod csinálni?',

    'actions' => [

        'cancel' => [
            'label' => 'Mégsem',
        ],

        'confirm' => [
            'label' => 'Megerősítés',
        ],

        'submit' => [
            'label' => 'Beküldés',
        ],

    ],

];
