<?php

return [

    'title' => 'Tilbakestill ditt passord',

    'heading' => 'Glemt passord?',

    'actions' => [

        'login' => [
            'label' => 'tilbake til logg inn',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'E-post adresse',
        ],

        'actions' => [

            'request' => [
                'label' => 'Send e-post',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'For mange forsøk',
            'body' => 'Vennligst forsøk igjen om :seconds sekunder.',
        ],

    ],

];
