<?php

return [

    'direction' => 'ltr',

    'actions' => [

        'billing' => [
            'label' => 'គ្រប់គ្រងការជាវ',
        ],

        'logout' => [
            'label' => 'ចាកចេញពីកម្មវិធីប្រព័ន្ធ',
        ],

        'open_database_notifications' => [
            'label' => 'បើកការជូនដំណឹង',
        ],

        'open_user_menu' => [
            'label' => 'ម៉ឺនុយអ្នកប្រើ',
        ],

        'sidebar' => [

            'collapse' => [
                'label' => 'បង្រួមរបារចំហៀង',
            ],

            'expand' => [
                'label' => 'ពង្រីករបារចំហៀង',
            ],

        ],

        'theme_switcher' => [

            'dark' => [
                'label' => 'បើកដំណើរការរចនាបទងងឹត',
            ],

            'light' => [
                'label' => 'បើករចនាបទពន្លឺ',
            ],

            'system' => [
                'label' => 'បើករចនាបទប្រព័ន្ធ',
            ],

        ],

    ],

    'avatar' => [
        'alt' => 'រូបតំណាង នៃ :name',
    ],

    'logo' => [
        'alt' => ':name និមិត្តសញ្ញា',
    ],

];
