<?php

return [

    'title' => 'Atkurti slaptažodį',

    'heading' => 'Pamiršote slaptažodį?',

    'actions' => [

        'login' => [
            'label' => 'grįžti į prisijungimą',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'El. paštas',
        ],

        'actions' => [

            'request' => [
                'label' => 'Siųsti',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'Per daug bandymų',
            'body' => 'Bandykite dar kartą už :seconds sekundžių.',
        ],

    ],

];
