<?php

return [

    'direction' => 'ltr',

    'actions' => [

        'billing' => [
            'label' => 'จัดการการสมัครสมาชิก',
        ],

        'logout' => [
            'label' => 'ออกจากระบบ',
        ],

        'open_database_notifications' => [
            'label' => 'เปิดการแจ้งเตือน',
        ],

        'open_user_menu' => [
            'label' => 'เมนูผู้ใช้',
        ],

        'sidebar' => [

            'collapse' => [
                'label' => 'ยุบแถบด้านข้าง',
            ],

            'expand' => [
                'label' => 'ขยายแถบด้านข้าง',
            ],

        ],

        'theme_switcher' => [

            'dark' => [
                'label' => 'เปลี่ยนเป็นธีมกลางคืน',
            ],

            'light' => [
                'label' => 'เปลี่ยนเป็นธีมกลางวัน',
            ],

            'system' => [
                'label' => 'เปลี่ยนเป็นธีมตามระบบ',
            ],

        ],

    ],

    'avatar' => [
        'alt' => 'รูปผู้ใช้ :name',
    ],

    'logo' => [
        'alt' => 'โลโก้ :name',
    ],

];
