<?php

return [

    'builder' => [

        'actions' => [

            'clone' => [
                'label' => 'Clonează',
            ],

            'add' => [
                'label' => 'Adăugare la :label',
            ],

            'add_between' => [
                'label' => 'Inserează',
            ],

            'delete' => [
                'label' => 'Ștergere',
            ],

            'reorder' => [
                'label' => 'Mutare',
            ],

            'move_down' => [
                'label' => 'Mutare în jos',
            ],

            'move_up' => [
                'label' => 'Mutare în sus',
            ],

            'collapse' => [
                'label' => 'Comprimare',
            ],

            'expand' => [
                'label' => 'Expandare',
            ],

            'collapse_all' => [
                'label' => 'Comprimare toate',
            ],

            'expand_all' => [
                'label' => 'Expandare toate',
            ],

        ],

    ],

    'checkbox_list' => [

        'actions' => [

            'deselect_all' => [
                'label' => 'Deselectează toate',
            ],

            'select_all' => [
                'label' => 'Selectează toate',
            ],

        ],

    ],

    'file_upload' => [

        'editor' => [

            'actions' => [

                'cancel' => [
                    'label' => 'Anulare',
                ],

                'drag_crop' => [
                    'label' => 'Mod de glisare "crop"',
                ],

                'drag_move' => [
                    'label' => 'Mod de glisare "move"',
                ],

                'flip_horizontal' => [
                    'label' => 'Întoarce imaginea pe orizontală',
                ],

                'flip_vertical' => [
                    'label' => 'Întoarce imaginea pe verticală',
                ],

                'move_down' => [
                    'label' => 'Mută imaginea mai jos',
                ],

                'move_left' => [
                    'label' => 'Mută imaginea in stânga',
                ],

                'move_right' => [
                    'label' => 'Mută imaginea in dreapta',
                ],

                'move_up' => [
                    'label' => 'Mută imaginea mai sus',
                ],

                'reset' => [
                    'label' => 'Reset',
                ],

                'rotate_left' => [
                    'label' => 'Rotește imaginea spre stânga',
                ],

                'rotate_right' => [
                    'label' => 'Rotește imaginea spre dreapta',
                ],

                'set_aspect_ratio' => [
                    'label' => 'Setează raportul de aspect la :ratio',
                ],

                'save' => [
                    'label' => 'Salvare',
                ],

                'zoom_100' => [
                    'label' => 'Mărește imaginea la 100%',
                ],

                'zoom_in' => [
                    'label' => 'Mărește',
                ],

                'zoom_out' => [
                    'label' => 'Micșorează',
                ],

            ],

            'fields' => [

                'height' => [
                    'label' => 'Înălțime',
                    'unit' => 'px',
                ],

                'rotation' => [
                    'label' => 'Rotire',
                    'unit' => 'deg',
                ],

                'width' => [
                    'label' => 'Lățime',
                    'unit' => 'px',
                ],

                'x_position' => [
                    'label' => 'X',
                    'unit' => 'px',
                ],

                'y_position' => [
                    'label' => 'Y',
                    'unit' => 'px',
                ],

            ],

            'aspect_ratios' => [

                'label' => 'Rapoarte de aspect',

                'no_fixed' => [
                    'label' => 'Liber',
                ],

            ],

            'svg' => [

                'messages' => [
                    'confirmation' => 'Modificarea fișierelor de tip SVG nu este recomandată deoarece poate cauza în pierderea calității în procesul de schimbare a dimensiunii.\n Sunteți sigur că doriți să continuați?',
                    'disabled' => 'Editarea fișierelor de tip SVG este dezactivată deoarece poate cauza în pierderea calității în procesul de schimbare a dimensiunii.',
                ],

            ],
        ],

    ],

    'key_value' => [

        'actions' => [

            'add' => [
                'label' => 'Adăugare linie',
            ],

            'delete' => [
                'label' => 'Ștergere linie',
            ],

            'reorder' => [
                'label' => 'Reordonare rând',
            ],

        ],

        'fields' => [

            'key' => [
                'label' => 'Cheie',
            ],

            'value' => [
                'label' => 'Valoare',
            ],

        ],

    ],

    'markdown_editor' => [

        'toolbar_buttons' => [
            'attach_files' => 'Atașare fișiere',
            'blockquote' => 'Citat',
            'bold' => 'Îngroșat',
            'bullet_list' => 'Listă cu puncte',
            'code_block' => 'Bloc de cod',
            'heading' => 'Titlu',
            'italic' => 'Cursiv',
            'link' => 'Link',
            'ordered_list' => 'Listă ordonată',
            'redo' => 'Refă',
            'strike' => 'Tăiat',
            'table' => 'Tabel',
            'undo' => 'Anulează',
        ],

    ],

    'radio' => [

        'boolean' => [
            'true' => 'Da',
            'false' => 'Nu',
        ],

    ],

    'repeater' => [

        'actions' => [

            'add' => [
                'label' => 'Adăugare la :label',
            ],

            'add_between' => [
                'label' => 'Inserează',
            ],

            'delete' => [
                'label' => 'Ștergere',
            ],

            'clone' => [
                'label' => 'Clonează',
            ],

            'reorder' => [
                'label' => 'Mutare',
            ],

            'move_down' => [
                'label' => 'Mutare în jos',
            ],

            'move_up' => [
                'label' => 'Mutare în sus',
            ],

            'collapse' => [
                'label' => 'Comprimare',
            ],

            'expand' => [
                'label' => 'Expandare',
            ],

            'collapse_all' => [
                'label' => 'Comprimare toate',
            ],

            'expand_all' => [
                'label' => 'Expandare toate',
            ],

        ],

    ],

    'rich_editor' => [

        'dialogs' => [

            'link' => [

                'actions' => [
                    'link' => 'Link',
                    'unlink' => 'Unlink',
                ],

                'label' => 'URL',

                'placeholder' => 'Introduceți URL-ul',

            ],

        ],

        'toolbar_buttons' => [
            'attach_files' => 'Atașare fișiere',
            'blockquote' => 'Citat',
            'bold' => 'Îngroșat',
            'bullet_list' => 'Listă cu puncte',
            'code_block' => 'Bloc de cod',
            'h1' => 'Titlu 1',
            'h2' => 'Titlu 2',
            'h3' => 'Titlu 3',
            'italic' => 'Cursiv',
            'link' => 'Link',
            'ordered_list' => 'Listă ordonată',
            'redo' => 'Refă',
            'strike' => 'Tăiat',
            'underline' => 'Subliniat',
            'undo' => 'Anulează',
        ],

    ],

    'select' => [

        'actions' => [

            'create_option' => [

                'modal' => [

                    'heading' => 'Adăugare opțiune',

                    'actions' => [

                        'create' => [
                            'label' => 'Adăugare',
                        ],

                        'create_another' => [
                            'label' => 'Creați și creați altul',
                        ],

                    ],

                ],

            ],

            'edit_option' => [

                'modal' => [

                    'heading' => 'Editare',

                    'actions' => [

                        'save' => [
                            'label' => 'Salvare',
                        ],

                    ],

                ],

            ],

        ],

        'boolean' => [
            'true' => 'Da',
            'false' => 'Nu',
        ],

        'loading_message' => 'Se încarcă...',

        'max_items_message' => 'Doar :count elemente pot fi selectate.',

        'no_search_results_message' => 'Nu s-a găsit nimic.',

        'placeholder' => 'Selectați o opțiune',

        'searching_message' => 'Căutare...',

        'search_prompt' => 'Începeți să tastați pentru a căuta',

    ],

    'tags_input' => [
        'placeholder' => 'Adăugați tag-uri',
    ],

    'text_input' => [

        'actions' => [

            'hide_password' => [
                'label' => 'Ascunde parola',
            ],

            'show_password' => [
                'label' => 'Afișează parola',
            ],

        ],

    ],

    'toggle_buttons' => [

        'boolean' => [
            'true' => 'Da',
            'false' => 'Nu',
        ],

    ],

    'wizard' => [

        'actions' => [

            'previous_step' => [
                'label' => 'Pasul anterior',
            ],

            'next_step' => [
                'label' => 'Pasul următor',
            ],

        ],

    ],

];
