<?php

return [

    'title' => 'ចូលក្នូងប្រព័ន្ធ',

    'heading' => 'ចូលទៅក្នុងគណនីរបស់អ្នក',

    'actions' => [

        'register' => [
            'before' => '​ឬ',
            'label' => 'ចុះឈ្មោះសម្រាប់គណនី',
        ],

        'request_password_reset' => [
            'label' => 'ភ្លេចពាក្យសម្ងាត់របស់អ្នក?',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'អាស័យ​ដ្ឋាន​អ៊ី​ម៉េ​ល',
        ],

        'password' => [
            'label' => 'ពាក្យសម្ងាត់',
        ],

        'remember' => [
            'label' => 'ចងចាំក្នុងប្រព័ន្ធនេះ',
        ],

        'actions' => [

            'authenticate' => [
                'label' => 'ចុះឈ្មោះចូល',
            ],

        ],

    ],

    'messages' => [

        'failed' => 'លិខិតសម្គាល់ទាំងនេះមិនត្រូវគ្នានឹងកំណត់ត្រាក្នុងប្រព័ន្ធរបស់យើងទេ។',

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'ការព្យាយាមចូលប្រើប្រាស់ច្រើនដងពេក',
            'body' => 'សូមព្យាយាមម្តងទៀតក្នុងរយៈពេល :seconds វិនាទី។.',
        ],

    ],

];
