<?php

return [

    'label' => 'प्रोफाइल',

    'form' => [

        'email' => [
            'label' => 'इमेल ठेगाना',
        ],

        'name' => [
            'label' => 'नाम',
        ],

        'password' => [
            'label' => 'नया पासवर्ड',
        ],

        'password_confirmation' => [
            'label' => 'नयाँ पासवर्ड पुष्टि गर्नुहोस्',
        ],

        'actions' => [

            'save' => [
                'label' => 'परिवर्तनहरू सुरक्षित गर्नुहोस',
            ],

        ],

    ],

    'notifications' => [

        'saved' => [
            'title' => 'सुरक्षित गरियो',
        ],

    ],

    'actions' => [

        'cancel' => [
            'label' => 'पछाडी',
        ],

    ],

];
