<?php

return [

    'title' => 'Ingia',

    'heading' => 'Ingia kwenye akaunti yako',

    'form' => [

        'email' => [
            'label' => 'Barua pepe',
        ],

        'password' => [
            'label' => 'Nenosiri',
        ],

        'remember' => [
            'label' => 'Nikumbuke',
        ],

        'actions' => [

            'authenticate' => [
                'label' => 'Ingia',
            ],

        ],

    ],

    'messages' => [

        'failed' => 'Hati hizi hazilingani na rekodi zetu.',

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'Majaribio mengi sana ya kuingia. Tafadhali jaribu tena ndani ya sekunde :seconds.',
        ],

    ],

];
