<?php

return [

    'label' => 'Urambazaji wa kurasa',

    'overview' => 'Onesha :first mpaka :last ya :total ya matokeo',

    'fields' => [

        'records_per_page' => [

            'label' => 'kwa kurasa',

            'options' => [
                'all' => 'Zote',
            ],

        ],

    ],

    'actions' => [

        'go_to_page' => [
            'label' => 'Nenda kwenye kurasa :page',
        ],

        'next' => [
            'label' => 'Mbele',
        ],

        'previous' => [
            'label' => 'Nyuma',
        ],

    ],

];
