<?php

return [

    'confirmation' => 'Ushbu amalni bajarishga ishonchingiz komilmi?',

    'actions' => [

        'cancel' => [
            'label' => 'Qaytarish',
        ],

        'confirm' => [
            'label' => 'Tasdiqlash',
        ],

        'submit' => [
            'label' => 'Yuborish',
        ],

    ],

];
