<?php

return [

    'builder' => [

        'actions' => [

            'clone' => [
                'label' => 'Duplikat',
            ],

            'add' => [

                'label' => 'Tambahkan :label',

                'modal' => [

                    'heading' => 'Tambah ke :label',

                    'actions' => [

                        'add' => [
                            'label' => 'Tambah',
                        ],

                    ],

                ],

            ],

            'add_between' => [

                'label' => 'Sisipkan',

                'modal' => [

                    'heading' => 'Tambah ke :label',

                    'actions' => [

                        'add' => [
                            'label' => 'Tambah',
                        ],

                    ],

                ],

            ],

            'delete' => [
                'label' => 'Hapus',
            ],

            'edit' => [

                'label' => 'Ubah',

                'modal' => [

                    'heading' => 'Ubah blok',

                    'actions' => [

                        'save' => [
                            'label' => 'Simpan perubahan',
                        ],

                    ],

                ],

            ],

            'reorder' => [
                'label' => 'Pindahkan',
            ],

            'move_down' => [
                'label' => 'Turunkan',
            ],

            'move_up' => [
                'label' => 'Naikkan',
            ],

            'collapse' => [
                'label' => 'Sembunyikan',
            ],

            'expand' => [
                'label' => 'Tampilkan',
            ],

            'collapse_all' => [
                'label' => 'Sembunyikan semua',
            ],

            'expand_all' => [
                'label' => 'Tampilkan semua',
            ],

        ],

    ],

    'checkbox_list' => [

        'actions' => [

            'deselect_all' => [
                'label' => 'Batalkan semua pilihan',
            ],

            'select_all' => [
                'label' => 'Pilih semua',
            ],

        ],

    ],

    'file_upload' => [

        'editor' => [

            'actions' => [

                'cancel' => [
                    'label' => 'Batal',
                ],

                'drag_crop' => [
                    'label' => 'Mode "potong"',
                ],

                'drag_move' => [
                    'label' => 'Mode "geser"',
                ],

                'flip_horizontal' => [
                    'label' => 'Balik gambar secara horizontal',
                ],

                'flip_vertical' => [
                    'label' => 'Balik gambar secara vertikal',
                ],

                'move_down' => [
                    'label' => 'Geser gambar ke bawah',
                ],

                'move_left' => [
                    'label' => 'Geser gambar ke kiri',
                ],

                'move_right' => [
                    'label' => 'Geser gambar ke kanan',
                ],

                'move_up' => [
                    'label' => 'Geser gambar ke atas',
                ],

                'reset' => [
                    'label' => 'Kembalikan',
                ],

                'rotate_left' => [
                    'label' => 'Putar gambar ke kiri',
                ],

                'rotate_right' => [
                    'label' => 'Putar gambar ke kanan',
                ],

                'set_aspect_ratio' => [
                    'label' => 'Tentukan aspek rasio ke :ratio',
                ],

                'save' => [
                    'label' => 'Simpan',
                ],

                'zoom_100' => [
                    'label' => 'Perbesar ke 100%',
                ],

                'zoom_in' => [
                    'label' => 'Perbesar',
                ],

                'zoom_out' => [
                    'label' => 'Perkecil',
                ],

            ],

            'fields' => [

                'height' => [
                    'label' => 'Tinggi',
                    'unit' => 'px',
                ],

                'rotation' => [
                    'label' => 'Putar',
                    'unit' => 'derajat',
                ],

                'width' => [
                    'label' => 'Lebar',
                    'unit' => 'px',
                ],

                'x_position' => [
                    'label' => 'X',
                    'unit' => 'px',
                ],

                'y_position' => [
                    'label' => 'Y',
                    'unit' => 'px',
                ],

            ],

            'aspect_ratios' => [

                'label' => 'Aspek rasio',

                'no_fixed' => [
                    'label' => 'Bebas',
                ],

            ],

            'svg' => [

                'messages' => [
                    'confirmation' => 'Mengedit file SVG tidak disarankan karena dapat mengakibatkan penurunan kualitas saat melakukan penskalaan.\n Apakah Anda yakin ingin melanjutkan?',
                    'disabled' => 'Pengeditan file SVG dinonaktifkan karena dapat mengakibatkan penurunan kualitas saat melakukan penskalaan.',
                ],

            ],

        ],

    ],

    'key_value' => [

        'actions' => [

            'add' => [
                'label' => 'Tambahkan baris',
            ],

            'delete' => [
                'label' => 'Hapus baris',
            ],

            'reorder' => [
                'label' => 'Ubah urutan baris',
            ],

        ],

        'fields' => [

            'key' => [
                'label' => 'Kunci',
            ],

            'value' => [
                'label' => 'Nilai',
            ],

        ],

    ],

    'markdown_editor' => [

        'toolbar_buttons' => [
            'attach_files' => 'Lampirkan berkas',
            'blockquote' => 'Kutipan',
            'bold' => 'Tebal',
            'bullet_list' => 'Daftar',
            'code_block' => 'Kode',
            'heading' => 'Judul',
            'italic' => 'Miring',
            'link' => 'Tautan',
            'ordered_list' => 'Daftar berurut',
            'redo' => 'Kembalikan',
            'strike' => 'Coret',
            'table' => 'Table',
            'undo' => 'Batalkan',
        ],

    ],

    'radio' => [

        'boolean' => [
            'true' => 'Ya',
            'false' => 'Tidak',
        ],

    ],

    'repeater' => [

        'actions' => [

            'add' => [
                'label' => 'Tambahkan :label',
            ],

            'add_between' => [
                'label' => 'Sisipkan',
            ],

            'delete' => [
                'label' => 'Hapus',
            ],

            'clone' => [
                'label' => 'Duplikat',
            ],

            'reorder' => [
                'label' => 'Pindahkan',
            ],

            'move_down' => [
                'label' => 'Turunkan',
            ],

            'move_up' => [
                'label' => 'Naikkan',
            ],

            'collapse' => [
                'label' => 'Sembunyikan',
            ],

            'expand' => [
                'label' => 'Tampilkan',
            ],

            'collapse_all' => [
                'label' => 'Sembunyikan semua',
            ],

            'expand_all' => [
                'label' => 'Tampilkan semua',
            ],

        ],

    ],

    'rich_editor' => [

        'dialogs' => [

            'link' => [

                'actions' => [
                    'link' => 'Buat tautan',
                    'unlink' => 'Batalkan tautan',
                ],

                'label' => 'Tautan',

                'placeholder' => 'Masukkan tautan',

            ],

        ],

        'toolbar_buttons' => [
            'attach_files' => 'Lampirkan berkas',
            'blockquote' => 'Kutipan',
            'bold' => 'Tebal',
            'bullet_list' => 'Daftar',
            'code_block' => 'Kode',
            'h1' => 'Judul',
            'h2' => 'Sub judul',
            'h3' => 'Anak judul',
            'italic' => 'Miring',
            'link' => 'Tautan',
            'ordered_list' => 'Daftar berurut',
            'redo' => 'Kembalikan',
            'strike' => 'Coret',
            'underline' => 'Garis bawah',
            'undo' => 'Batalkan',
        ],

    ],

    'select' => [

        'actions' => [

            'create_option' => [

                'modal' => [

                    'heading' => 'Buat',

                    'actions' => [

                        'create' => [
                            'label' => 'Buat',
                        ],

                        'create_another' => [
                            'label' => 'Buat & buat lainnya',
                        ],

                    ],

                ],

            ],

            'edit_option' => [

                'modal' => [

                    'heading' => 'Ubah',

                    'actions' => [

                        'save' => [
                            'label' => 'Simpan',
                        ],

                    ],

                ],

            ],

        ],

        'boolean' => [
            'true' => 'Ya',
            'false' => 'Tidak',
        ],

        'loading_message' => 'Memuat...',

        'max_items_message' => 'Hanya :count yang dapat dipilih.',

        'no_search_results_message' => 'Tidak ada hasil yang sesuai dengan pencarian Anda.',

        'placeholder' => 'Pilih salah satu opsi',

        'searching_message' => 'Sedang mencari...',

        'search_prompt' => 'Ketik untuk mencari...',

    ],

    'tags_input' => [
        'placeholder' => 'Tag baru',
    ],

    'text_input' => [

        'actions' => [

            'hide_password' => [
                'label' => 'Sembunyikan kata sandi',
            ],

            'show_password' => [
                'label' => 'Tampilkan kata sandi',
            ],

        ],

    ],

    'toggle_buttons' => [

        'boolean' => [
            'true' => 'Ya',
            'false' => 'Tidak',
        ],

    ],

    'wizard' => [

        'actions' => [

            'previous_step' => [
                'label' => 'Sebelumnya',
            ],

            'next_step' => [
                'label' => 'Selanjutnya',
            ],

        ],

    ],

];
