<?php

namespace Filament\Pages\Actions;

use Filament\Actions\ReplicateAction as BaseAction;

/**
 * @deprecated Use `\Filament\Actions\ReplicateAction` instead.
 */
class ReplicateAction extends BaseAction {}
