<?php

return [

    'label' => 'Профіль',

    'form' => [

        'email' => [
            'label' => 'Електронна пошта',
        ],

        'name' => [
            'label' => 'Ім\'я',
        ],

        'password' => [
            'label' => 'Новий пароль',
        ],

        'password_confirmation' => [
            'label' => 'Введіть новий пароль ще раз',
        ],

        'actions' => [

            'save' => [
                'label' => 'Зберегти зміни',
            ],

        ],

    ],

    'notifications' => [

        'saved' => [
            'title' => 'Збережено',
        ],

    ],

    'actions' => [

        'cancel' => [
            'label' => 'Відмінити',
        ],

    ],

];
