<?php

return [

    'direction' => 'rtl',

    'actions' => [

        'billing' => [
            'label' => 'נהל מנוי',
        ],

        'logout' => [
            'label' => 'התנתק',
        ],

        'open_database_notifications' => [
            'label' => 'פתח התראות',
        ],

        'open_user_menu' => [
            'label' => 'תפריט משתמש',
        ],

        'sidebar' => [

            'collapse' => [
                'label' => 'כווץ תפריט צד',
            ],

            'expand' => [
                'label' => 'הרחב תפריט צד',
            ],

        ],

        'theme_switcher' => [

            'dark' => [
                'label' => 'הפעל מצב כהה',
            ],

            'light' => [
                'label' => 'הפעל מצב מואר',
            ],

            'system' => [
                'label' => 'הפעל ערכת נושא של המערכת',
            ],

        ],

    ],

];
