<?php

return [

    'title' => 'Нууц үг сэргээх',

    'heading' => 'Нууц үгээ мартсан уу?',

    'actions' => [

        'login' => [
            'label' => 'нэвтрэх хэсэг рүү буцах',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'Имэйл хаяг',
        ],

        'actions' => [

            'request' => [
                'label' => 'Имэйл илгээх',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'Олон тооны хүсэлт',
            'body' => ':seconds секундын дараа дахин оролдоно уу!',
        ],

    ],

];
