<?php

return [

    'label' => 'Экспорт :label',

    'modal' => [

        'heading' => 'Экспорт :label',

        'form' => [

            'columns' => [

                'label' => 'Баганууд',

                'form' => [

                    'is_enabled' => [
                        'label' => ':column нээлттэй',
                    ],

                    'label' => [
                        'label' => ':column нэр',
                    ],

                ],

            ],

        ],

        'actions' => [

            'export' => [
                'label' => 'Экспорт',
            ],

        ],

    ],

    'notifications' => [

        'completed' => [

            'title' => 'Экспорт дууссан',

            'actions' => [

                'download_csv' => [
                    'label' => 'Татаж авах .csv',
                ],

                'download_xlsx' => [
                    'label' => 'Татаж авах .xlsx',
                ],

            ],

        ],

        'max_rows' => [
            'title' => 'Экспорт хэт том байна',
            'body' => 'Та нэг удаад нэгээс олон мөр экспортлох боломжгүй.|Та нэг удаад :count - с олон мөр экспортлох боломжгүй.',
        ],

        'started' => [
            'title' => 'Экспорт эхлэлээ',
            'body' => 'Таны 1 мөрийг экспорт хийх үйлдэл эхлэсэн. Үйлдэл дууссаны дараа та татаж авах холбоостой мэдэгдэл хүлээн авах болно.|Таны :count мөрийг экспорт хийх үйлдэл эхлэсэн. Үйлдэл дууссаны дараа та татаж авах холбоостой мэдэгдэл хүлээн авах болно.',
        ],

    ],

    'file_name' => 'export-:export_id-:model',

];
