<?php

return [

    'title' => 'Մուտք',

    'heading' => 'Մուտք գործեք ձեր հաշիվ',

    'form' => [

        'email' => [
            'label' => 'Էլ. փոստի հասցե',
        ],

        'password' => [
            'label' => 'Գաղտնաբառ',
        ],

        'remember' => [
            'label' => 'Հիշել',
        ],

        'actions' => [

            'authenticate' => [
                'label' => 'Մուտք գործել',
            ],

        ],

    ],

    'messages' => [

        'failed' => 'Այս տվյալները չեն համապատասխանում մեր տվյալներին։',

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'Չափից շատ մուտք գործելու փորձեր։ Խնդրում ենք նորից փորձեք :seconds վայրկյանից։',
        ],

    ],

];
