<?php

return [

    'title' => 'بازنشانی رمز عبور',

    'heading' => 'رمز عبور خود را فراموش کرده‌اید؟',

    'actions' => [

        'login' => [
            'label' => 'بازگشت به ورود',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'ایمیل',
        ],

        'actions' => [

            'request' => [
                'label' => 'ارسال ایمیل',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'شما بیش از حد مجاز درخواست داشته‌اید.',
            'body' => 'لطفاً :seconds ثانیه دیگر تلاش کنید.',
        ],

    ],

];
