<?php

return [

    'confirmation' => 'Ar tikrai norite tai atlikti?',

    'actions' => [

        'cancel' => [
            'label' => 'Atšaukti',
        ],

        'confirm' => [
            'label' => 'Patvirtinti',
        ],

        'submit' => [
            'label' => 'Pateikti',
        ],

    ],

];
