<?php

return [

    'direction' => 'ltr', // 'ltr' (left-to-right) is standard for Nepali text, but if you're accommodating for languages that read right-to-left, you might dynamically switch this.

    'actions' => [

        'billing' => [
            'label' => 'सदस्यता व्यवस्थापन गर्नुहोस्',
        ],

        'logout' => [
            'label' => 'साइन आउट',
        ],

        'open_database_notifications' => [
            'label' => 'सूचनाहरू खोल्नुहोस्',
        ],

        'open_user_menu' => [
            'label' => 'प्रयोगकर्ता मेनु',
        ],

        'sidebar' => [

            'collapse' => [
                'label' => 'साइडबार भत्काउनुहोस्',
            ],

            'expand' => [
                'label' => 'साइडबार विस्तार गर्नुहोस्',
            ],

        ],

        'theme_switcher' => [

            'dark' => [
                'label' => 'गाढा थिम सक्रिय गर्नुहोस्',
            ],

            'light' => [
                'label' => 'उज्यालो थिम सक्रिय गर्नुहोस्',
            ],

            'system' => [
                'label' => 'सिस्टम थिम सक्रिय गर्नुहोस्',
            ],

        ],

    ],

];
