<?php

return [

    'builder' => [

        'actions' => [

            'clone' => [
                'label' => 'Nusxalash',
            ],

            'add' => [
                'label' => ':labelga qo\'shish',

                'modal' => [

                    'heading' => ':labelga qo\'shish',

                    'actions' => [

                        'add' => [
                            'label' => 'Qo\'shish',
                        ],

                    ],

                ],
            ],

            'add_between' => [
                'label' => 'Orasiga kiritish',

                'modal' => [

                    'heading' => ':labelga qo\'shish',

                    'actions' => [

                        'add' => [
                            'label' => 'Qo\'shish',
                        ],

                    ],

                ],
            ],

            'delete' => [
                'label' => 'O\'chirish',
            ],

            'edit' => [

                'label' => 'O\'zgartirish',

                'modal' => [

                    'heading' => 'O\'zgartirish',

                    'actions' => [

                        'save' => [
                            'label' => 'O\'zgarishlarni saqlash',
                        ],

                    ],

                ],

            ],

            'reorder' => [
                'label' => 'Ko\'chirish',
            ],

            'move_down' => [
                'label' => 'Pastga ko\'chirish',
            ],

            'move_up' => [
                'label' => 'Yuqoriga ko\'chirish',
            ],

            'collapse' => [
                'label' => 'Yig\'ish',
            ],

            'expand' => [
                'label' => 'Yoyish',
            ],

            'collapse_all' => [
                'label' => 'Barchasini yig\'ish',
            ],

            'expand_all' => [
                'label' => 'Barchasini yoyish',
            ],

        ],

    ],

    'checkbox_list' => [

        'actions' => [

            'deselect_all' => [
                'label' => 'Barchasini tanlamaslik',
            ],

            'select_all' => [
                'label' => 'Barchasini belgilash',
            ],

        ],

    ],

    'file_upload' => [

        'editor' => [

            'actions' => [

                'cancel' => [
                    'label' => 'Bekor qilish',
                ],

                'drag_crop' => [
                    'label' => 'Kesish rejimi',
                ],

                'drag_move' => [
                    'label' => 'Ko\'chirish rejimi',
                ],

                'flip_horizontal' => [
                    'label' => 'Gorizontal ravishda aylantirish',
                ],

                'flip_vertical' => [
                    'label' => 'Vertikal ravishda aylantirish',
                ],

                'move_down' => [
                    'label' => 'Pastga ko\'chirish',
                ],

                'move_left' => [
                    'label' => 'Chapga ko\'chirish',
                ],

                'move_right' => [
                    'label' => 'O\'ngga ko\'chirish',
                ],

                'move_up' => [
                    'label' => 'Yuqoriga ko\'chirish',
                ],

                'reset' => [
                    'label' => 'Qayta o\'rnatish',
                ],

                'rotate_left' => [
                    'label' => 'Chapga burish',
                ],

                'rotate_right' => [
                    'label' => 'O\'ngga burish',
                ],

                'set_aspect_ratio' => [
                    'label' => 'Aspekt nisbati :ratio',
                ],

                'save' => [
                    'label' => 'Saqlash',
                ],

                'zoom_100' => [
                    'label' => '100% gacha oshirish',
                ],

                'zoom_in' => [
                    'label' => 'Kattalashtirish',
                ],

                'zoom_out' => [
                    'label' => 'Kichiklashtirish',
                ],

            ],

            'fields' => [

                'height' => [
                    'label' => 'Balandlik',
                    'unit' => 'px',
                ],

                'rotation' => [
                    'label' => 'Aylanish',
                    'unit' => 'gradus',
                ],

                'width' => [
                    'label' => 'Kenglik',
                    'unit' => 'px',
                ],

                'x_position' => [
                    'label' => 'X',
                    'unit' => 'px',
                ],

                'y_position' => [
                    'label' => 'Y',
                    'unit' => 'px',
                ],

            ],

            'aspect_ratios' => [

                'label' => 'Aspekt nisbatlari',

                'no_fixed' => [
                    'label' => 'Erkin',
                ],

            ],

            'svg' => [

                'messages' => [
                    'confirmation' => 'SVG fayllarni tahrirlash tavsiya etilmaydi, chunki masshtab o‘tkazishda sifat yo‘qolishi mumkin.\n Davom etishni xohlaysizmi?',
                    'disabled' => 'SVG fayllarini tahrirlash bloklangan, chunki masshtab oʻlchashda sifat yoʻqolishi mumkin.',
                ],

            ],

        ],

    ],

    'key_value' => [

        'actions' => [

            'add' => [
                'label' => 'Qator qo\'shish',
            ],

            'delete' => [
                'label' => 'Qatorni o\'chirish',
            ],
            'reorder' => [
                'label' => 'Qatorni ko\'chirish',
            ],

        ],

        'fields' => [

            'key' => [
                'label' => 'Kalit so\'z',
            ],

            'value' => [
                'label' => 'Qiymat',
            ],

        ],

    ],

    'markdown_editor' => [
        'toolbar_buttons' => [
            'attach_files' => 'Fayl biriktirish',
            'blockquote' => 'Iqtibos',
            'bold' => 'Qalin',
            'bullet_list' => 'Nuqtalangan ro\'yxat',
            'code_block' => 'Kod',
            'heading' => 'Sarlavha',
            'italic' => 'Burilgan',
            'link' => 'Havola',
            'ordered_list' => 'Raqamli ro\'yxat',
            'redo' => 'Qaytarish',
            'strike' => 'Chizilgan',
            'table' => 'Jadval',
            'undo' => 'Bekor qilish',
        ],

    ],

    'repeater' => [

        'actions' => [

            'add' => [
                'label' => ':label qo\'shish',
            ],

            'add_between' => [
                'label' => 'Orasiga qo\'shish',
            ],

            'delete' => [
                'label' => 'O\'chirish',
            ],

            'clone' => [
                'label' => 'Nusxalash (klonlash)',
            ],

            'reorder' => [
                'label' => 'Ko\'chirish',
            ],

            'move_down' => [
                'label' => 'Pastga ko\'chirish',
            ],

            'move_up' => [
                'label' => 'Yuqoriga ko\'chirish',
            ],

            'collapse' => [
                'label' => 'Yig\'ish',
            ],

            'expand' => [
                'label' => 'Yoyish',
            ],

            'collapse_all' => [
                'label' => 'Barchasini yig\'ish',
            ],

            'expand_all' => [
                'label' => 'Barchasini yoyish',
            ],

        ],

    ],

    'rich_editor' => [

        'dialogs' => [

            'link' => [

                'actions' => [
                    'link' => 'Havola',
                    'unlink' => 'Havolani o\'chirish',
                ],

                'label' => 'URL',

                'placeholder' => 'URLni kiritish',

            ],

        ],

        'toolbar_buttons' => [
            'attach_files' => 'Fayl biriktirish',
            'blockquote' => 'Iqtibos',
            'bold' => 'Qalin',
            'bullet_list' => 'Nuqtalangan ro\'yxat',
            'code_block' => 'Kod',
            'h1' => 'Nomi',
            'h2' => 'Sarlavha',
            'h3' => 'Subtitr',
            'italic' => 'Burilgan',
            'link' => 'Havola',
            'ordered_list' => 'Raqamli ro\'yxat',
            'redo' => 'Qaytarish',
            'strike' => 'Chizilgan',
            'underline' => 'Pastki chiziq',
            'undo' => 'Bekor qilish',
        ],

    ],

    'select' => [

        'actions' => [

            'create_option' => [

                'modal' => [

                    'heading' => 'Yaratish',

                    'actions' => [

                        'create' => [
                            'label' => 'Yaratish',
                        ],
                        'create_another' => [
                            'label' => 'Yana boshqa yaratish',
                        ],

                    ],

                ],

            ],

            'edit_option' => [

                'modal' => [

                    'heading' => 'Tahrirlash',

                    'actions' => [

                        'save' => [
                            'label' => 'Saqlash',
                        ],

                    ],

                ],

            ],

        ],

        'boolean' => [
            'true' => 'Xa',
            'false' => 'Yoq',
        ],

        'loading_message' => 'Yuklanmoqda...',

        'max_items_message' => 'Faqat :countta tanlash mumkin.',

        'no_search_results_message' => 'So\'rovingizga mos keladigan natijalar yo\'q.',

        'placeholder' => 'Variant tanlash',

        'searching_message' => 'Qidirilmoqda...',

        'search_prompt' => 'Qidiruv uchun matn kiriting...',
    ],

    'tags_input' => [
        'placeholder' => 'Yangi teg',
    ],

    'text_input' => [

        'actions' => [

            'hide_password' => [
                'label' => 'Parolni yashirish',
            ],

            'show_password' => [
                'label' => 'Parolni ko\'rsatish',
            ],

        ],

    ],

    'toggle_buttons' => [

        'boolean' => [
            'true' => 'Ha',
            'false' => 'Yo\'q',
        ],

    ],

    'wizard' => [

        'actions' => [

            'previous_step' => [
                'label' => 'Orqaga',
            ],

            'next_step' => [
                'label' => 'Keyingi',
            ],

        ],

    ],

];
