<?php

return [

    'confirmation' => 'Sei sicuro di volerlo fare?',

    'actions' => [

        'cancel' => [
            'label' => 'Annulla',
        ],

        'confirm' => [
            'label' => 'Conferma',
        ],

        'submit' => [
            'label' => 'Invia',
        ],

    ],

];
