<?php

namespace Filament\Pages\Actions;

use Filament\Actions\CreateAction as BaseAction;

/**
 * @deprecated Use `\Filament\Actions\CreateAction` instead.
 */
class CreateAction extends BaseAction {}
