<?php

return [

    'builder' => [

        'actions' => [

            'clone' => [
                'label' => 'ក្លូន',
            ],

            'add' => [
                'label' => 'បន្ថែម​លើ :label',
            ],

            'add_between' => [
                'label' => 'បញ្ចូលរវាងប្លុក',
            ],

            'delete' => [
                'label' => 'លុប',
            ],

            'reorder' => [
                'label' => 'ផ្លាស់ទី',
            ],

            'move_down' => [
                'label' => 'ទៅ​ក្រោម',
            ],

            'move_up' => [
                'label' => 'ផ្លាស់ទីឡើងលើ',
            ],

            'collapse' => [
                'label' => 'ដួលរលំ',
            ],

            'expand' => [
                'label' => 'ពង្រីក',
            ],

            'collapse_all' => [
                'label' => 'ដួលរលំទាំងអស់។',
            ],

            'expand_all' => [
                'label' => 'ពង្រីកទាំងអស់។',
            ],

        ],

    ],

    'checkbox_list' => [

        'actions' => [

            'deselect_all' => [
                'label' => 'ដកការជ្រើសរើសទាំងអស់',
            ],

            'select_all' => [
                'label' => 'ជ្រើសរើសទាំងអស់',
            ],

        ],

    ],

    'file_upload' => [

        'editor' => [

            'actions' => [

                'cancel' => [
                    'label' => 'លុបចោល',
                ],

                'drag_crop' => [
                    'label' => 'របៀបអូសដោយ "ច្រឹប"',
                ],

                'drag_move' => [
                    'label' => 'របៀបអូសដោយ "ផ្លាស់ទី"',
                ],

                'flip_horizontal' => [
                    'label' => 'ត្រឡប់​រូបភាពតាមជួរដេក',
                ],

                'flip_vertical' => [
                    'label' => 'ត្រឡប់​រូបភាពតាមជួរឈរ',
                ],

                'move_down' => [
                    'label' => 'រំកិលរូបភាពចុះក្រោម',
                ],

                'move_left' => [
                    'label' => 'រំកិលរូបភាពទៅឆ្វេង',
                ],

                'move_right' => [
                    'label' => 'រំកិលរូបភាពទៅស្តាំ',
                ],

                'move_up' => [
                    'label' => 'រំកិលរូបភាពទៅលើ',
                ],

                'reset' => [
                    'label' => 'កំណត់ឡើងវិញ',
                ],

                'rotate_left' => [
                    'label' => 'បង្វិលរូបភាពទៅឆ្វេង',
                ],

                'rotate_right' => [
                    'label' => 'បង្វិលរូបភាពទៅស្តាំ',
                ],

                'set_aspect_ratio' => [
                    'label' => 'កំណត់សមាមាត្រទំហំទៅ :ratio',
                ],

                'save' => [
                    'label' => 'រក្សាទុក',
                ],

                'zoom_100' => [
                    'label' => 'ប្តូរទំហំរូបភាពទៅ១០០%',
                ],

                'zoom_in' => [
                    'label' => 'ពង្រីក',
                ],

                'zoom_out' => [
                    'label' => 'បង្រួម',
                ],

            ],

            'fields' => [

                'height' => [
                    'label' => 'កំពស់',
                    'unit' => 'px',
                ],

                'rotation' => [
                    'label' => 'ការបង្វិល',
                    'unit' => 'deg',
                ],

                'width' => [
                    'label' => 'ទទឹង',
                    'unit' => 'px',
                ],

                'x_position' => [
                    'label' => 'X',
                    'unit' => 'px',
                ],

                'y_position' => [
                    'label' => 'Y',
                    'unit' => 'px',
                ],

            ],

            'aspect_ratios' => [

                'label' => 'សមាមាត្រទំហំ',

                'no_fixed' => [
                    'label' => 'មិនកំណត់',
                ],

            ],

            'svg' => [

                'messages' => [
                    'confirmation' => 'ការកែសម្រួលឯកសារ SVG មិនត្រូវបានណែនាំទេ ព្រោះវាអាចបណ្តាលឱ្យបាត់បង់គុណភាពនៅពេលធ្វើមាត្រដ្ឋាន។\n តើអ្នកប្រាកដថាចង់បន្តទេ?',
                    'disabled' => 'ការកែសម្រួលឯកសារ SVG ត្រូវបានបិទព្រោះវាអាចបណ្តាលឱ្យបាត់បង់គុណភាពនៅពេលធ្វើមាត្រដ្ឋាន។',
                ],

            ],

        ],

    ],

    'key_value' => [

        'actions' => [

            'add' => [
                'label' => 'បន្ថែមជួរ',
            ],

            'delete' => [
                'label' => 'លុបជួរ',
            ],

            'reorder' => [
                'label' => 'តម្រៀបជួរម្តងទៀត',
            ],

        ],

        'fields' => [

            'key' => [
                'label' => 'គន្លឺះ',
            ],

            'value' => [
                'label' => 'តម្លៃ',
            ],

        ],

    ],

    'markdown_editor' => [

        'toolbar_buttons' => [
            'attach_files' => 'ភ្ជាប់ឯកសារ',
            'blockquote' => 'ប្លុកសម្រង់',
            'bold' => 'ដិត',
            'bullet_list' => 'បញ្ជីគ្រាប់',
            'code_block' => 'ប្លុកកូដ',
            'heading' => 'Heading',
            'italic' => 'ទ្រេត',
            'link' => 'តំណភ្ជាប់',
            'ordered_list' => 'បញ្ជីលេខ',
            'redo' => 'ធ្វើឡើងវិញ',
            'strike' => 'ការវាយឆ្មក់',
            'table' => 'តុ',
            'undo' => 'មិនធ្វើវិញ',
        ],

    ],

    'radio' => [

        'boolean' => [
            'true' => 'បាទ',
            'false' => 'ទេ',
        ],

    ],

    'repeater' => [

        'actions' => [

            'add' => [
                'label' => 'បន្ថែម​លើ :label',
            ],

            'add_between' => [
                'label' => 'បញ្ចូលរវាង',
            ],

            'delete' => [
                'label' => 'លុប',
            ],

            'clone' => [
                'label' => 'ក្លូន',
            ],

            'reorder' => [
                'label' => 'ផ្លាស់ទី',
            ],

            'move_down' => [
                'label' => 'ទៅ​ក្រោម',
            ],

            'move_up' => [
                'label' => 'ផ្លាស់ទីឡើងលើ',
            ],

            'collapse' => [
                'label' => 'ដួលរលំ',
            ],

            'expand' => [
                'label' => 'ពង្រីក',
            ],

            'collapse_all' => [
                'label' => 'ដួលរលំទាំងអស់។',
            ],

            'expand_all' => [
                'label' => 'ពង្រីកទាំងអស់។',
            ],

        ],

    ],

    'rich_editor' => [

        'dialogs' => [

            'link' => [

                'actions' => [
                    'link' => 'តំណភ្ជាប់',
                    'unlink' => 'ផ្ដាច់',
                ],

                'label' => 'URL',

                'placeholder' => 'បញ្ចូល URL',

            ],

        ],

        'toolbar_buttons' => [
            'attach_files' => 'ភ្ជាប់ឯកសារ',
            'blockquote' => 'ប្លុកសម្រង់',
            'bold' => 'ដិត',
            'bullet_list' => 'បញ្ជីគ្រាប់',
            'code_block' => 'ប្លុកកូដ',
            'h1' => 'ចំណងជើង',
            'h2' => 'ក្បាល',
            'h3' => 'ចំណងជើងរង',
            'italic' => 'ទ្រេត',
            'link' => 'តំណភ្ជាប់',
            'ordered_list' => 'បញ្ជីលេខ',
            'redo' => 'ធ្វើឡើងវិញ',
            'strike' => 'ការវាយឆ្មក់',
            'underline' => 'គូសបន្ទាត់ពីក្រោម',
            'undo' => 'មិនធ្វើវិញ',
        ],

    ],

    'select' => [

        'actions' => [

            'create_option' => [

                'modal' => [

                    'heading' => 'បង្កើត',

                    'actions' => [

                        'create' => [
                            'label' => 'បង្កើត',
                        ],

                        'create_another' => [
                            'label' => 'បង្កើត & បង្កើតឡើងវិញ',
                        ],

                    ],

                ],

            ],

            'edit_option' => [

                'modal' => [

                    'heading' => 'កែសម្រួល',

                    'actions' => [

                        'save' => [
                            'label' => 'រក្សាទុក',
                        ],

                    ],

                ],

            ],

        ],

        'boolean' => [
            'true' => 'បាទ',
            'false' => 'ទេ',
        ],

        'loading_message' => 'កំពុងផ្ទុក...',

        'max_items_message' => 'តែប៉ុណ្ណោះ :count អាចត្រូវបានជ្រើសរើស.',

        'no_search_results_message' => 'មិនមានជម្រើសត្រូវជាមួយការស្វែងរក.',

        'placeholder' => 'ជ្រើសរើសជម្រើស',

        'searching_message' => 'ស្វែងរក...',

        'search_prompt' => 'ចាប់ផ្តើមសសេរដើម្បីស្វែងរក...',

    ],

    'tags_input' => [
        'placeholder' => 'ស្លាកថ្មី។',
    ],

    'text_input' => [

        'actions' => [

            'hide_password' => [
                'label' => 'លាក់ពាក្យសម្ងាត់',
            ],

            'show_password' => [
                'label' => 'បង្ហាញពាក្យសម្ងាត់',
            ],

        ],

    ],

    'toggle_buttons' => [

        'boolean' => [
            'true' => 'បាទ',
            'false' => 'ទេ',
        ],

    ],

    'wizard' => [

        'actions' => [

            'previous_step' => [
                'label' => 'ត្រឡប់មកវិញ',
            ],

            'next_step' => [
                'label' => 'បន្ទាប់',
            ],

        ],

    ],

];
