<?php

return [

    'actions' => [

        'open_documentation' => [
            'label' => 'Dokumentácia',
        ],

        'open_github' => [
            'label' => 'GitHub',
        ],

    ],

];
