<?php

return [

    'title' => 'نوێکردنەوەی وشەی نهێنی',

    'heading' => 'وشەی نهێنیت لەبیر کردووە؟?',

    'actions' => [

        'login' => [
            'label' => 'گەڕانەوە بۆ چوونەژوورەوە',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'ئیمەیڵ',
        ],

        'actions' => [

            'request' => [
                'label' => 'ناردنی ئیمەیڵ',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'داواکاری زۆر نێردرا',
            'body' => 'تکایە هەوڵ بدەرەوە دوای :seconds چرکە.',
        ],

    ],

];
