<?php

return [

    'single' => [

        'label' => '分离',

        'modal' => [

            'heading' => '分离 :label',

            'actions' => [

                'detach' => [
                    'label' => '分离',
                ],

            ],

        ],

        'notifications' => [

            'detached' => [
                'title' => '已分离',
            ],

        ],

    ],

    'multiple' => [

        'label' => '分离已选项目',

        'modal' => [

            'heading' => '分离已选 :label',

            'actions' => [

                'detach' => [
                    'label' => '分离已选项目',
                ],

            ],

        ],

        'notifications' => [

            'detached' => [
                'title' => '已分离',
            ],

        ],

    ],

];
