<?php

return [

    'confirmation' => 'Oletko varma että haluat tehdä tämän?',

    'actions' => [

        'cancel' => [
            'label' => 'Peruuta',
        ],

        'confirm' => [
            'label' => 'Vahvista',
        ],

        'submit' => [
            'label' => 'Lähetä',
        ],

    ],

];
