<?php

return [

    'label' => 'ប្រវត្តិរូប',

    'form' => [

        'email' => [
            'label' => 'អាស័យដ្ធានអ៊ីម៉ែល',
        ],

        'name' => [
            'label' => 'ឈ្មោះ',
        ],

        'password' => [
            'label' => 'ពាក្យសម្ងាត់ថ្មី',
        ],

        'password_confirmation' => [
            'label' => 'បញ្ជាក់ពាក្យសម្ងាត់ថ្មី',
        ],

        'actions' => [

            'save' => [
                'label' => 'រក្សាទុកការផ្លាស់ប្តូរ',
            ],

        ],

    ],

    'notifications' => [

        'saved' => [
            'title' => 'បានរក្សាទុក',
        ],

    ],

    'actions' => [

        'cancel' => [
            'label' => 'លុបចោល',
        ],

    ],

];
