<?php

return [

    'confirmation' => '您确定要这样操作吗?',

    'actions' => [

        'cancel' => [
            'label' => '取消',
        ],

        'confirm' => [
            'label' => '确定',
        ],

        'submit' => [
            'label' => '提交',
        ],

    ],

];
