<?php

return [

    'label' => 'Profile',

    'form' => [

        'email' => [
            'label' => 'Email address',
        ],

        'name' => [
            'label' => 'Name',
        ],

        'password' => [
            'label' => 'New password',
        ],

        'password_confirmation' => [
            'label' => 'Confirm new password',
        ],

        'actions' => [

            'save' => [
                'label' => 'Save changes',
            ],

        ],

    ],

    'notifications' => [

        'saved' => [
            'title' => 'Saved',
        ],

    ],

    'actions' => [

        'cancel' => [
            'label' => 'Cancel',
        ],

    ],

];
