<?php

return [

    'builder' => [

        'actions' => [

            'clone' => [
                'label' => 'Iga',
            ],

            'add' => [
                'label' => 'Ongeza kwenye :label',
            ],

            'add_between' => [
                'label' => 'Ingiza',
            ],

            'delete' => [
                'label' => 'Futa',
            ],

            'reorder' => [
                'label' => 'Hamisha',
            ],

            'move_down' => [
                'label' => 'Sogeza chini',
            ],

            'move_up' => [
                'label' => 'Sogeza juu',
            ],

            'collapse' => [
                'label' => 'Kunja',
            ],

            'expand' => [
                'label' => 'Kunjua',
            ],

            'collapse_all' => [
                'label' => 'Kunja zote',
            ],

            'expand_all' => [
                'label' => 'Kunjua zote',
            ],

        ],

    ],

    'key_value' => [

        'actions' => [

            'add' => [
                'label' => 'Ongeza safu',
            ],

            'delete' => [
                'label' => 'Futa safu',
            ],

            'reorder' => [
                'label' => 'Pangilia safu',
            ],

        ],

        'fields' => [

            'key' => [
                'label' => 'Ufunguo',
            ],

            'value' => [
                'label' => 'Thamani',
            ],

        ],

    ],

    'markdown_editor' => [

        'toolbar_buttons' => [
            'attach_files' => 'Ambatisha faili',
            'bold' => 'Nzito',
            'bullet_list' => 'Orodha ya vitone',
            'code_block' => 'Kizuizi cha msimbo',
            'edit' => 'Hariri',
            'italic' => 'Italiki',
            'link' => 'Kiungo',
            'ordered_list' => 'Orodha yenye nambari',
            'preview' => 'Onyesha awali',
            'strike' => 'Piga kupitia',
        ],

    ],

    'repeater' => [

        'actions' => [

            'add' => [
                'label' => 'Ongeza kwenye :label',
            ],

            'delete' => [
                'label' => 'Futa',
            ],

            'clone' => [
                'label' => 'Iga',
            ],

            'reorder' => [
                'label' => 'Hamisha',
            ],

            'move_down' => [
                'label' => 'Sogeza chini',
            ],

            'move_up' => [
                'label' => 'Sogeza juu',
            ],

            'collapse' => [
                'label' => 'Kunja',
            ],

            'expand' => [
                'label' => 'Kunjua',
            ],

            'collapse_all' => [
                'label' => 'Kunja zote',
            ],

            'expand_all' => [
                'label' => 'Kunjua zote',
            ],

        ],

    ],

    'rich_editor' => [

        'dialogs' => [

            'link' => [

                'actions' => [
                    'link' => 'Unganisha',
                    'unlink' => 'Tenganisha',
                ],

                'label' => 'URL',

                'placeholder' => 'Ingiza URL',

            ],

        ],

        'toolbar_buttons' => [
            'attach_files' => 'Ambatisha faili',
            'blockquote' => 'Nukuu ya kuzuia',
            'bold' => 'Nzito',
            'bullet_list' => 'Orodha ya vitone',
            'code_block' => 'Kizuizi cha msimbo',
            'h1' => 'Kichwa',
            'h2' => 'Kichwa',
            'h3' => 'Kichwa kidogo',
            'italic' => 'Italiki',
            'link' => 'Link',
            'ordered_list' => 'Orodha yenye nambari',
            'redo' => 'Rudia',
            'strike' => 'Piga kupitia',
            'undo' => 'Tendua',
        ],

    ],

    'select' => [

        'actions' => [

            'create_option' => [

                'modal' => [

                    'heading' => 'Tengeneza',

                    'actions' => [

                        'create' => [
                            'label' => 'Tengeneza',
                        ],

                    ],

                ],

            ],

        ],

        'boolean' => [
            'true' => 'Ndio',
            'false' => 'Hapana',
        ],

        'loading_message' => 'Inapakia...',

        'max_items_message' => 'Ni :count pekee ndiyo inaweza kuchaguliwa.',

        'no_search_results_message' => 'Hakuna chaguzi zinazolingana na utafutaji wako.',

        'placeholder' => 'Chagua chaguo',

        'searching_message' => 'Inatafuta...',

        'search_prompt' => 'Anza kuandika ili kufafuta...',

    ],

    'tags_input' => [
        'placeholder' => 'Lebo mpya',
    ],

    'wizard' => [

        'actions' => [

            'previous_step' => [
                'label' => 'Nyuma',
            ],

            'next_step' => [
                'label' => 'Mbele',
            ],

        ],

    ],

];
