<?php

return [

    'single' => [

        'label' => 'Poista lopullisesti',

        'modal' => [

            'heading' => 'Pakota poistaminen :label',

            'actions' => [

                'delete' => [
                    'label' => 'Poista',
                ],

            ],

        ],

        'notifications' => [

            'deleted' => [
                'title' => 'Tietue poistettu',
            ],

        ],

    ],

    'multiple' => [

        'label' => 'Poista valitut lopullisesti',

        'modal' => [

            'heading' => 'Poista valitut lopullisesti :label',

            'actions' => [

                'delete' => [
                    'label' => 'Poista',
                ],

            ],

        ],

        'notifications' => [

            'deleted' => [
                'title' => 'Tietueet poistettu',
            ],

        ],

    ],

];
