<?php

namespace Filament\Pages\Actions;

use Filament\Actions\ActionGroup as BaseActionGroup;

/**
 * @deprecated Use `\Filament\Actions\ActionGroup` instead.
 */
class ActionGroup extends BaseActionGroup {}
