<?php

return [

    'single' => [

        'label' => '削除',

        'modal' => [

            'heading' => ':label 削除',

            'actions' => [

                'delete' => [
                    'label' => '削除',
                ],

            ],

        ],

        'notifications' => [

            'deleted' => [
                'title' => '削除しました',
            ],

        ],

    ],

    'multiple' => [

        'label' => '選択中を削除',

        'modal' => [

            'heading' => '選択中の:labelを削除',

            'actions' => [

                'delete' => [
                    'label' => '削除',
                ],

            ],

        ],

        'notifications' => [

            'deleted' => [
                'title' => '削除しました',
            ],

        ],

    ],

];
