<?php

return [

    'label' => 'โปรไฟล์',

    'form' => [

        'email' => [
            'label' => 'ที่อยู่อีเมล',
        ],

        'name' => [
            'label' => 'ชื่อ',
        ],

        'password' => [
            'label' => 'รหัสผ่านใหม่',
        ],

        'password_confirmation' => [
            'label' => 'ยืนยันรหัสผ่านใหม่',
        ],

        'actions' => [

            'save' => [
                'label' => 'บันทึก',
            ],

        ],

    ],

    'notifications' => [

        'saved' => [
            'title' => 'บันทึกข้อมูลเรียบร้อย',
        ],

    ],

    'actions' => [

        'cancel' => [
            'label' => 'ยกเลิก',
        ],

    ],

];
