<?php

return [

    'direction' => 'ltr',

    'actions' => [

        'billing' => [
            'label' => 'Správa předplatného',
        ],

        'logout' => [
            'label' => 'Odhlásit se',
        ],

        'open_database_notifications' => [
            'label' => 'Zobrazit notifikace',
        ],

        'open_user_menu' => [
            'label' => 'Nabídka uživatele',
        ],

        'sidebar' => [

            'collapse' => [
                'label' => 'Skrýt boční panel',
            ],

            'expand' => [
                'label' => 'Otevřít boční panel',
            ],

        ],

        'theme_switcher' => [

            'dark' => [
                'label' => 'Zapnout tmavý režim',
            ],

            'light' => [
                'label' => 'Zapnout světlý režim',
            ],

            'system' => [
                'label' => 'Použít nastavení systému',
            ],

        ],

    ],

    'avatar' => [
        'alt' => 'Profilový obrázek pro :name',
    ],

    'logo' => [
        'alt' => ':name logo',
    ],

];
