<?php

return [

    'label' => 'プロフィール',

    'form' => [

        'email' => [
            'label' => 'メールアドレス',
        ],

        'name' => [
            'label' => '名前',
        ],

        'password' => [
            'label' => '新しいパスワード',
        ],

        'password_confirmation' => [
            'label' => '新しいパスワードの確認',
        ],

        'actions' => [

            'save' => [
                'label' => '変更を保存',
            ],

        ],

    ],

    'notifications' => [

        'saved' => [
            'title' => '保存しました',
        ],

    ],

    'actions' => [

        'cancel' => [
            'label' => 'キャンセル',
        ],

    ],

];
