<?php

return [

    'direction' => 'rtl',

    'actions' => [

        'billing' => [
            'label' => 'بەشدارییەکان',
        ],

        'logout' => [
            'label' => 'چوونەدەرەوە',
        ],

        'open_database_notifications' => [
            'label' => 'کردنەوەی ئاگانامەکان',
        ],

        'open_user_menu' => [
            'label' => 'مێنیوی بەکارهێنەر',
        ],

        'sidebar' => [

            'collapse' => [
                'label' => 'بچووکردنەوەی شریتی گەڕان',
            ],

            'expand' => [
                'label' => 'فراوانکردنی شریتی گەڕان',
            ],

        ],

        'theme_switcher' => [

            'dark' => [
                'label' => 'گۆڕینی ڕوانگە بۆ تاریک',
            ],

            'light' => [
                'label' => 'گۆڕینی ڕوانگە بۆ ڕووناک',
            ],

            'system' => [
                'label' => 'داگرساندنی باری سیستەم',
            ],

        ],

    ],

];
