<?php

return [

    'confirmation' => 'Bunu yapmak istediğinizden emin misiniz?',

    'actions' => [

        'cancel' => [
            'label' => 'İptal',
        ],

        'confirm' => [
            'label' => 'Onayla',
        ],

        'submit' => [
            'label' => 'Gönder',
        ],

    ],

];
