<?php

return [

    'builder' => [

        'actions' => [

            'clone' => [
                'label' => 'Klonuoti',
            ],

            'add' => [
                'label' => 'Pridėti prie :label',
            ],

            'add_between' => [
                'label' => 'Pridėti tarp blokų',
            ],

            'delete' => [
                'label' => 'Ištrinti',
            ],

            'reorder' => [
                'label' => 'Pastumti',
            ],

            'move_down' => [
                'label' => 'Žemyn',
            ],

            'move_up' => [
                'label' => 'Aukštyn',
            ],

            'collapse' => [
                'label' => 'Suskleisti',
            ],

            'expand' => [
                'label' => 'Išskleisti',
            ],

            'collapse_all' => [
                'label' => 'Suskleisti viską',
            ],

            'expand_all' => [
                'label' => 'Išskleisti viską',
            ],

        ],

    ],

    'checkbox_list' => [

        'actions' => [

            'deselect_all' => [
                'label' => 'Atžymėti viską',
            ],

            'select_all' => [
                'label' => 'Pasirinkti viską',
            ],

        ],

    ],

    'file_upload' => [

        'editor' => [

            'actions' => [

                'cancel' => [
                    'label' => 'Atšaukti',
                ],

                'drag_crop' => [
                    'label' => 'Apkirpti velkant',
                ],

                'drag_move' => [
                    'label' => 'Perkelti velkant',
                ],

                'flip_horizontal' => [
                    'label' => 'Apversti nuotrauką horizontaliai',
                ],

                'flip_vertical' => [
                    'label' => 'Apversti nuotrauką vertikaliai',
                ],

                'move_down' => [
                    'label' => 'Perkelti vaizdą žemyn',
                ],

                'move_left' => [
                    'label' => 'Perkelti vaizdą į kairę',
                ],

                'move_right' => [
                    'label' => 'Perkelti vaizdą į dešinę',
                ],

                'move_up' => [
                    'label' => 'Perkelti vaizdą aukštyn',
                ],

                'reset' => [
                    'label' => 'Atstatyti',
                ],

                'rotate_left' => [
                    'label' => 'Pasukti nuotrauką į kairę',
                ],

                'rotate_right' => [
                    'label' => 'Pasukti nuotrauka į dešinę',
                ],

                'set_aspect_ratio' => [
                    'label' => 'Nustatyti kraštinių santikį į :ratio',
                ],

                'save' => [
                    'label' => 'Išsaugoti',
                ],

                'zoom_100' => [
                    'label' => 'Priartinti nuotrauką iki 100%',
                ],

                'zoom_in' => [
                    'label' => 'Priartinti',
                ],

                'zoom_out' => [
                    'label' => 'Atitraukti',
                ],

            ],

            'fields' => [

                'height' => [
                    'label' => 'Aukštis',
                    'unit' => 'px',
                ],

                'rotation' => [
                    'label' => 'Rotacija',
                    'unit' => 'deg',
                ],

                'width' => [
                    'label' => 'Plotis',
                    'unit' => 'px',
                ],

                'x_position' => [
                    'label' => 'X',
                    'unit' => 'px',
                ],

                'y_position' => [
                    'label' => 'Y',
                    'unit' => 'px',
                ],

            ],

            'aspect_ratios' => [

                'label' => 'Kraštinių santykiai',

                'no_fixed' => [
                    'label' => 'Laisvas',
                ],

            ],

            'svg' => [

                'messages' => [
                    'confirmation' => 'Redaguoti SVG failų nerekomenduojama, kadangi tai gali įtakoti kokybės praradimą keičiant mastelį.\n Ar tikrai norite tęsti?',
                    'disabled' => 'SVG failų redagavimas išjungtas, kadangi tai gali įtakoti kokybės praradimą keičiant mastelį.',
                ],

            ],

        ],

    ],

    'key_value' => [

        'actions' => [

            'add' => [
                'label' => 'Pridėti eilutę',
            ],

            'delete' => [
                'label' => 'Ištrinti eilutę',
            ],

            'reorder' => [
                'label' => 'Pastumti',
            ],

        ],

        'fields' => [

            'key' => [
                'label' => 'Raktas',
            ],

            'value' => [
                'label' => 'Reikšmė',
            ],

        ],

    ],

    'radio' => [

        'boolean' => [
            'true' => 'Taip',
            'false' => 'Ne',
        ],

    ],

    'markdown_editor' => [

        'toolbar_buttons' => [
            'attach_files' => 'Pridėti failus',
            'blockquote' => 'Citatos blokas',
            'bold' => 'Paryškinta',
            'bullet_list' => 'Ženklų sąrašas',
            'code_block' => 'Kodo blokas',
            'heading' => 'Antraštė',
            'italic' => 'Kursyvu',
            'link' => 'Nuoroda',
            'ordered_list' => 'Sunumeruotas sąrašas',
            'redo' => 'Perdaryti',
            'strike' => 'Perbraukti',
            'table' => 'Lentelė',
            'undo' => 'Anuliuoti',
        ],

    ],

    'repeater' => [

        'actions' => [

            'add' => [
                'label' => 'Pridėti prie :label',
            ],

            'add_between' => [
                'label' => 'Pridėti tarp',
            ],

            'delete' => [
                'label' => 'Ištrinti',
            ],

            'clone' => [
                'label' => 'Klonuoti',
            ],

            'reorder' => [
                'label' => 'Pastumti',
            ],

            'move_down' => [
                'label' => 'Žemyn',
            ],

            'move_up' => [
                'label' => 'Aukštyn',
            ],

            'collapse' => [
                'label' => 'Suskleisti',
            ],

            'expand' => [
                'label' => 'Išskleisti',
            ],

            'collapse_all' => [
                'label' => 'Suskleisti viską',
            ],

            'expand_all' => [
                'label' => 'Išskleisti viską',
            ],

        ],

    ],

    'rich_editor' => [

        'dialogs' => [

            'link' => [

                'actions' => [
                    'link' => 'Pridėti saitą',
                    'unlink' => 'Pašalinti saitą',
                ],

                'label' => 'Svetainės adresas',

                'placeholder' => 'Įveskite svetainės adresą',

            ],

        ],

        'toolbar_buttons' => [
            'attach_files' => 'Pridėti failus',
            'blockquote' => 'Citatos blokas',
            'bold' => 'Paryškinta',
            'bullet_list' => 'Ženklų sąrašas',
            'code_block' => 'Kodo blokas',
            'h1' => 'Pavadinimas',
            'h2' => 'Antraštė',
            'h3' => 'Paantraštė',
            'italic' => 'Kursyvas',
            'link' => 'Nuoroda',
            'ordered_list' => 'Sunumeruotas sąrašas',
            'redo' => 'Perdaryti',
            'strike' => 'Perbraukta',
            'underline' => 'Pabraukta',
            'undo' => 'Anuliuoti',
        ],

    ],

    'select' => [

        'actions' => [

            'create_option' => [

                'modal' => [

                    'heading' => 'Sukurti',

                    'actions' => [

                        'create' => [
                            'label' => 'Sukurti',
                        ],

                        'create_another' => [
                            'label' => 'Sukurti ir sukurti kitą',
                        ],

                    ],

                ],

            ],

            'edit_option' => [

                'modal' => [

                    'heading' => 'Redaguoti',

                    'actions' => [

                        'save' => [
                            'label' => 'Išsaugoti',
                        ],

                    ],

                ],

            ],

        ],

        'boolean' => [
            'true' => 'Taip',
            'false' => 'Ne',
        ],

        'loading_message' => 'Kraunasi...',

        'max_items_message' => 'Pažymėti gali būti tik :count .',

        'no_search_results_message' => 'Nėra paieškos rezultatų.',

        'placeholder' => 'Pasirinkite',

        'searching_message' => 'Ieškoma...',

        'search_prompt' => 'Pradėkite rašykite paieškai...',

    ],

    'tags_input' => [
        'placeholder' => 'Nauja žyma',
    ],

    'text_input' => [

        'actions' => [

            'hide_password' => [
                'label' => 'Slėpti slaptažodį',
            ],

            'show_password' => [
                'label' => 'Rodyti slaptažodį',
            ],

        ],

    ],

    'toggle_buttons' => [

        'boolean' => [
            'true' => 'Taip',
            'false' => 'Ne',
        ],

    ],

    'wizard' => [

        'actions' => [

            'previous_step' => [
                'label' => 'Atgal',
            ],

            'next_step' => [
                'label' => 'Pirmyn',
            ],

        ],

    ],

];
