<?php

return [

    'builder' => [

        'actions' => [

            'clone' => [
                'label' => 'پۆشتەکردن',
            ],

            'add' => [
                'label' => 'زیادکردن بۆ :label',
            ],

            'add_between' => [
                'label' => 'داخڵکردن لە نێوان هێڵ',
            ],

            'delete' => [
                'label' => 'سڕینەوە',
            ],

            'reorder' => [
                'label' => 'جوڵاندن',
            ],

            'move_down' => [
                'label' => 'جوڵاندن بۆ خوارەوە',
            ],

            'move_up' => [
                'label' => 'جوڵاندن بۆ سەرەوە',
            ],

            'collapse' => [
                'label' => 'بچووکردنەوە',
            ],

            'expand' => [
                'label' => 'فراوانکردن',
            ],

            'collapse_all' => [
                'label' => 'بچووکردنەوەی هەموو',
            ],

            'expand_all' => [
                'label' => 'فراوانکردنی هەموو',
            ],

        ],

    ],

    'checkbox_list' => [

        'actions' => [

            'deselect_all' => [
                'label' => 'لابردنی هەموو دیاریکراوەکان',
            ],

            'select_all' => [
                'label' => 'دیاریکردنی هەموو',
            ],

        ],

    ],

    'file_upload' => [

        'editor' => [

            'actions' => [

                'cancel' => [
                    'label' => 'پاشگەزبوونەوە',
                ],

                'drag_crop' => [
                    'label' => 'جۆری ڕاکێشان "بڕین"',
                ],

                'drag_move' => [
                    'label' => 'جۆری ڕاکێشان "جوڵاندن"',
                ],

                'flip_horizontal' => [
                    'label' => 'وەرگێڕانی وێنە بە ئاسۆی',
                ],

                'flip_vertical' => [
                    'label' => 'وەرگێڕانی وێنە بە ستونی',
                ],

                'move_down' => [
                    'label' => 'جوڵاندنی وێنە بۆ خوارەوە',
                ],

                'move_left' => [
                    'label' => 'جوڵاندنی وێنە بۆ چەپ',
                ],

                'move_right' => [
                    'label' => 'جوڵاندنی وێنە بۆ ڕاست',
                ],

                'move_up' => [
                    'label' => 'جوڵاندنی وێنە بۆ سەرەوە',
                ],

                'reset' => [
                    'label' => 'دۆخی سەرەتا',
                ],

                'rotate_left' => [
                    'label' => 'سوڕانەوەی وێنە بۆ چەپ',
                ],

                'rotate_right' => [
                    'label' => 'سوڕانەوەی وێنە بۆ ڕاست',
                ],

                'set_aspect_ratio' => [
                    'label' => 'دانانی تێکڕای لاکان بۆ :ratio',
                ],

                'save' => [
                    'label' => 'نوێکردنەوە',
                ],

                'zoom_100' => [
                    'label' => 'نزیکردنەوەی وێنە بۆ ١٠٠%',
                ],

                'zoom_in' => [
                    'label' => 'نزیککردنەوە',
                ],

                'zoom_out' => [
                    'label' => 'دوورخستنەوە',
                ],

            ],

            'fields' => [

                'height' => [
                    'label' => 'بەرزی',
                    'unit' => 'px',
                ],

                'rotation' => [
                    'label' => 'سوڕانەوە',
                    'unit' => 'پلە',
                ],

                'width' => [
                    'label' => 'پانی',
                    'unit' => 'px',
                ],

                'x_position' => [
                    'label' => 'X',
                    'unit' => 'px',
                ],

                'y_position' => [
                    'label' => 'Y',
                    'unit' => 'px',
                ],

            ],

            'aspect_ratios' => [

                'label' => 'تێکڕای لاکان',

                'no_fixed' => [
                    'label' => 'سەربەخۆ',
                ],

            ],

        ],

    ],

    'key_value' => [

        'actions' => [

            'add' => [
                'label' => 'زیادکردنی ڕیز',
            ],

            'delete' => [
                'label' => 'سڕینەوەی ڕیز',
            ],

            'reorder' => [
                'label' => 'ڕێکخستنی ڕیز',
            ],

        ],

        'fields' => [

            'key' => [
                'label' => 'کلیل',
            ],

            'value' => [
                'label' => 'نرخ',
            ],

        ],

    ],

    'markdown_editor' => [

        'toolbar_buttons' => [
            'attach_files' => 'لکاندنی فایل',
            'blockquote' => 'هێڵی وتە',
            'bold' => 'تۆخ کردن',
            'bullet_list' => 'لیستی خاڵ',
            'code_block' => 'هێڵی کۆد',
            'heading' => 'ناونیشان',
            'italic' => 'لارکردن',
            'link' => 'بەستەر',
            'ordered_list' => 'لیستی ژمارە',
            'redo' => 'دووبارەکردن',
            'strike' => 'هێڵ بەسەرهێنان',
            'table' => 'خشتە',
            'undo' => 'گەڕانەوە',
        ],

    ],

    'repeater' => [

        'actions' => [

            'add' => [
                'label' => 'زیادکردن بۆ :label',
            ],

            'delete' => [
                'label' => 'سڕینەوە',
            ],

            'clone' => [
                'label' => 'پۆشتەکردن',
            ],

            'reorder' => [
                'label' => 'جوڵاندن',
            ],

            'move_down' => [
                'label' => 'جوڵاندن بۆ خوارەوە',
            ],

            'move_up' => [
                'label' => 'جوڵاندن بۆ سەرەوە',
            ],

            'collapse' => [
                'label' => 'بچووکردنەوە',
            ],

            'expand' => [
                'label' => 'فراوانکردن',
            ],

            'collapse_all' => [
                'label' => 'بچووکردنەوەی هەموو',
            ],

            'expand_all' => [
                'label' => 'فراوانکردنی هەموو',
            ],

        ],

    ],

    'rich_editor' => [

        'dialogs' => [

            'link' => [

                'actions' => [
                    'link' => 'بەستەر',
                    'unlink' => 'لابردنی بەستەر',
                ],

                'label' => 'بەستەر',

                'placeholder' => 'بەستەر داخڵ بکە',

            ],

        ],

        'toolbar_buttons' => [
            'attach_files' => 'لکاندنی فایل',
            'blockquote' => 'هێڵی وتە',
            'bold' => 'تۆخ کردن',
            'bullet_list' => 'لیستی خاڵ',
            'code_block' => 'هێڵی کۆد',
            'h1' => 'ناونیشان',
            'h2' => 'ناونیشانی دووەم',
            'h3' => 'ناونیشانی سێیەم',
            'italic' => 'لارکردن',
            'link' => 'بەستەر',
            'ordered_list' => 'لیستی ژمارە',
            'redo' => 'دووبارەکردن',
            'strike' => 'هێڵ بەسەرهێنان',
            'underline' => 'هێڵ بەژێرهێنان',
            'undo' => 'گەڕانەوە',
        ],

    ],

    'select' => [

        'actions' => [

            'create_option' => [

                'modal' => [

                    'heading' => 'دروستکردن',

                    'actions' => [

                        'create' => [
                            'label' => 'دروستکردن',
                        ],

                        'create_another' => [
                            'label' => 'دروستکردن و تۆمارێکی تر',
                        ],

                    ],

                ],

            ],

            'edit_option' => [

                'modal' => [

                    'heading' => 'دەسکاریکردن',

                    'actions' => [

                        'save' => [
                            'label' => 'نوێکردنەوە',
                        ],

                    ],

                ],

            ],

        ],

        'boolean' => [
            'true' => 'بەڵێ',
            'false' => 'نەخێر',
        ],

        'loading_message' => 'چاوەروان بە...',

        'max_items_message' => 'تەنها :count دەتواندرێت دیاری بکرێت.',

        'no_search_results_message' => 'هیچ هەڵبژاردەیەک بۆ گەڕانەکەت نەدۆزرایەوە.',

        'placeholder' => 'هەڵبژاردەیەک دیاری بکە',

        'searching_message' => 'گەڕان...',

        'search_prompt' => 'دەستبکە بە نوسین بۆ گەڕان...',

    ],

    'tags_input' => [
        'placeholder' => 'تاگی نوێ',
    ],

    'wizard' => [

        'actions' => [

            'previous_step' => [
                'label' => 'پێشوو',
            ],

            'next_step' => [
                'label' => 'دواتر',
            ],

        ],

    ],

];
