<?php

return [

    'builder' => [

        'actions' => [

            'clone' => [
                'label' => 'Klonēt',
            ],

            'add' => [
                'label' => 'Izveidot :label',
            ],

            'add_between' => [
                'label' => 'Ievietot',
            ],

            'delete' => [
                'label' => 'Dzēst',
            ],

            'reorder' => [
                'label' => 'Pārkārtot',
            ],

            'move_down' => [
                'label' => 'Pārvietot uz leju',
            ],

            'move_up' => [
                'label' => 'Pārvietot uz augšu',
            ],

            'collapse' => [
                'label' => 'Sakļaut',
            ],

            'expand' => [
                'label' => 'Izplest',
            ],

            'collapse_all' => [
                'label' => 'Sakļaut visus',
            ],

            'expand_all' => [
                'label' => 'Izplest visus',
            ],

        ],

    ],

    'checkbox_list' => [

        'actions' => [

            'deselect_all' => [
                'label' => 'Noņemt atlasi visiem',
            ],

            'select_all' => [
                'label' => 'Atlasīt visus',
            ],

        ],

    ],

    'file_upload' => [

        'editor' => [

            'actions' => [

                'cancel' => [
                    'label' => 'Atcelt',
                ],

                'drag_crop' => [
                    'label' => 'Režīms "kadrēšana"',
                ],

                'drag_move' => [
                    'label' => 'Režīms "pārvietošana"',
                ],

                'flip_horizontal' => [
                    'label' => 'Attēlot horizontāli',
                ],

                'flip_vertical' => [
                    'label' => 'Attēlot vertikāli',
                ],

                'move_down' => [
                    'label' => 'Pārvietot uz leju',
                ],

                'move_left' => [
                    'label' => 'Pārvietot pa kreisi',
                ],

                'move_right' => [
                    'label' => 'Pārvietot pa labi',
                ],

                'move_up' => [
                    'label' => 'Pārvietot uz augšu',
                ],

                'reset' => [
                    'label' => 'Atiestatīt',
                ],

                'rotate_left' => [
                    'label' => 'Pagriezt pa kreisi',
                ],

                'rotate_right' => [
                    'label' => 'Pagriezt pa labi',
                ],

                'set_aspect_ratio' => [
                    'label' => 'Iestatīt malu attiecību :ratio',
                ],

                'save' => [
                    'label' => 'Saglabāt',
                ],

                'zoom_100' => [
                    'label' => 'Pietuvināt līdz 100%',
                ],

                'zoom_in' => [
                    'label' => 'Pietuvināt',
                ],

                'zoom_out' => [
                    'label' => 'Attālināt',
                ],

            ],

            'fields' => [

                'height' => [
                    'label' => 'Augstums',
                    'unit' => 'px',
                ],

                'rotation' => [
                    'label' => 'Rotācija',
                    'unit' => 'grādi',
                ],

                'width' => [
                    'label' => 'Platums',
                    'unit' => 'px',
                ],

                'x_position' => [
                    'label' => 'X',
                    'unit' => 'px',
                ],

                'y_position' => [
                    'label' => 'Y',
                    'unit' => 'px',
                ],

            ],

            'aspect_ratios' => [

                'label' => 'Malu attiecība',

                'no_fixed' => [
                    'label' => 'Brīva',
                ],

            ],

            'svg' => [

                'messages' => [
                    'confirmation' => 'SVG failu rediģēšana nav ieteicama, jo mērogošanas laikā var tikt zaudēta kvalitāte.\n Vai tiešām vēlaties turpināt?',
                    'disabled' => 'SVG failu rediģēšana ir atspējota, jo mērogošanas laikā var tikt zaudēta kvalitāte.',
                ],

            ],

        ],

    ],

    'key_value' => [

        'actions' => [

            'add' => [
                'label' => 'Pievienot rindu',
            ],

            'delete' => [
                'label' => 'Dzēst rindu',
            ],

            'reorder' => [
                'label' => 'Pārkārtot rindu',
            ],

        ],

        'fields' => [

            'key' => [
                'label' => 'Atslēga',
            ],

            'value' => [
                'label' => 'Vērtība',
            ],

        ],

    ],

    'markdown_editor' => [

        'toolbar_buttons' => [
            'attach_files' => 'Pievienot failus',
            'blockquote' => 'Citāts',
            'bold' => 'Treknraksts',
            'bullet_list' => 'Nekārtots saraksts',
            'code_block' => 'Koda bloks',
            'heading' => 'Virsraksts',
            'italic' => 'Slīpraksts',
            'link' => 'Saite',
            'ordered_list' => 'Numurēts saraksts',
            'redo' => 'Atcelt atsaukšanu',
            'strike' => 'Pārsvītrojums',
            'table' => 'Tabula',
            'undo' => 'Atsaukt',
        ],

    ],

    'repeater' => [

        'actions' => [

            'add' => [
                'label' => 'Pievienot :label',
            ],

            'add_between' => [
                'label' => 'Pievienot starp',
            ],

            'delete' => [
                'label' => 'Dzēst',
            ],

            'clone' => [
                'label' => 'Klonēt',
            ],

            'reorder' => [
                'label' => 'Pārvietot',
            ],

            'move_down' => [
                'label' => 'Pārvietot uz leju',
            ],

            'move_up' => [
                'label' => 'Pārvietot uz augšu',
            ],

            'collapse' => [
                'label' => 'Sakļaut',
            ],

            'expand' => [
                'label' => 'Izplest',
            ],

            'collapse_all' => [
                'label' => 'Sakļaut visus',
            ],

            'expand_all' => [
                'label' => 'Izplest visus',
            ],

        ],

    ],

    'rich_editor' => [

        'dialogs' => [

            'link' => [

                'actions' => [
                    'link' => 'Saistīt',
                    'unlink' => 'Noņemt saiti',
                ],

                'label' => 'Saite',

                'placeholder' => 'Ievadīt saiti',

            ],

        ],

        'toolbar_buttons' => [
            'attach_files' => 'Pievienot failus',
            'blockquote' => 'Citāts',
            'bold' => 'Treknraksts',
            'bullet_list' => 'Nekārtots saraksts',
            'code_block' => 'Koda bloks',
            'h1' => 'Virsraksts',
            'h2' => 'Mazāks virsraksts',
            'h3' => 'Pakārtotā iedaļa',
            'italic' => 'Slīpraksts',
            'link' => 'Saite',
            'ordered_list' => 'Numurēts saraksts',
            'redo' => 'Atcelt atsaukšanu',
            'strike' => 'Pārsvītrojums',
            'underline' => 'Pasvītrojums',
            'undo' => 'Atsaukt',
        ],

    ],

    'select' => [

        'actions' => [

            'create_option' => [

                'modal' => [

                    'heading' => 'Izveidot',

                    'actions' => [

                        'create' => [
                            'label' => 'Izveidot',
                        ],

                        'create_another' => [
                            'label' => 'Izveidot vēl vienu',
                        ],

                    ],

                ],

            ],

            'edit_option' => [

                'modal' => [

                    'heading' => 'Rediģēt',

                    'actions' => [

                        'save' => [
                            'label' => 'Saglabāt',
                        ],

                    ],

                ],

            ],

        ],

        'boolean' => [
            'true' => 'Jā',
            'false' => 'Nē',
        ],

        'loading_message' => 'Ielādē...',

        'max_items_message' => 'Tikai :count var atzīmēt.',

        'no_search_results_message' => 'Jūsu meklēšanai neatbilst neviena opcija.',

        'placeholder' => 'Atlasiet opciju',

        'searching_message' => 'Meklē...',

        'search_prompt' => 'Sāciet rakstīt, lai meklētu...',

    ],

    'tags_input' => [
        'placeholder' => 'Izveidot birku',
    ],

    'wizard' => [

        'actions' => [

            'previous_step' => [
                'label' => 'Iepriekšējais',
            ],

            'next_step' => [
                'label' => 'Nākamais',
            ],

        ],

    ],

];
