<?php

return [

    'confirmation' => 'Вы уверены, что хотите это сделать?',

    'actions' => [

        'cancel' => [
            'label' => 'Отменить',
        ],

        'confirm' => [
            'label' => 'Подтвердить',
        ],

        'submit' => [
            'label' => 'Отправить',
        ],

    ],

];
