<?php

return [

    'title' => 'Khôi phục mật khẩu',

    'heading' => 'Quên mật khẩu?',

    'actions' => [

        'login' => [
            'label' => 'quay lại đăng nhập',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'Địa chỉ email',
        ],

        'actions' => [

            'request' => [
                'label' => 'Gửi email',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'Quá nhiều yêu cầu',
            'body' => 'Vui lòng thử lại sau :seconds giây.',
        ],

    ],

];
