<?php

return [

    'builder' => [

        'actions' => [

            'clone' => [
                'label' => 'שכפל',
            ],

            'add' => [
                'label' => 'הוסף ל :label',
            ],

            'add_between' => [
                'label' => 'הכנס בין הבלוקים',
            ],

            'delete' => [
                'label' => 'מחק',
            ],

            'reorder' => [
                'label' => 'העבר',
            ],

            'move_down' => [
                'label' => 'הזז מטה',
            ],

            'move_up' => [
                'label' => 'הזז מעלה',
            ],

            'collapse' => [
                'label' => 'צמצם',
            ],

            'expand' => [
                'label' => 'הרחב',
            ],

            'collapse_all' => [
                'label' => 'צמצם הכל',
            ],

            'expand_all' => [
                'label' => 'הרחב הכל',
            ],

        ],

    ],

    'checkbox_list' => [

        'actions' => [

            'deselect_all' => [
                'label' => 'בטל בחירה בהכל',
            ],

            'select_all' => [
                'label' => 'בחר הכל',
            ],

        ],

    ],

    'file_upload' => [

        'editor' => [

            'actions' => [

                'cancel' => [
                    'label' => 'ביטול',
                ],

                'drag_crop' => [
                    'label' => 'מצב גרירה "חיתוך"',
                ],

                'drag_move' => [
                    'label' => 'מצב גרירה "הזזה"',
                ],

                'flip_horizontal' => [
                    'label' => 'היפוך אופקי של התמונה',
                ],

                'flip_vertical' => [
                    'label' => 'היפוך אנכי של התמונה',
                ],

                'move_down' => [
                    'label' => 'הזזת התמונה למטה',
                ],

                'move_left' => [
                    'label' => 'הזזת התמונה לשמאל',
                ],

                'move_right' => [
                    'label' => 'הזזת התמונה לימין',
                ],

                'move_up' => [
                    'label' => 'הזזת התמונה למעלה',
                ],

                'reset' => [
                    'label' => 'איפוס',
                ],

                'rotate_left' => [
                    'label' => 'סיבוב התמונה שמאלה',
                ],

                'rotate_right' => [
                    'label' => 'סיבוב התמונה ימינה',
                ],

                'set_aspect_ratio' => [
                    'label' => 'הגדר יחס צדדי לתמונה :ratio',
                ],

                'save' => [
                    'label' => 'שמור',
                ],

                'zoom_100' => [
                    'label' => 'התמונה עם זום 100%',
                ],

                'zoom_in' => [
                    'label' => 'התקרב',
                ],

                'zoom_out' => [
                    'label' => 'התרחק',
                ],

            ],

            'fields' => [

                'height' => [
                    'label' => 'גובה',
                    'unit' => 'פיקסלים',
                ],

                'rotation' => [
                    'label' => 'סיבוב',
                    'unit' => 'מעלות',
                ],

                'width' => [
                    'label' => 'רוחב',
                    'unit' => 'פיקסלים',
                ],

                'x_position' => [
                    'label' => 'X',
                    'unit' => 'פיקסלים',
                ],

                'y_position' => [
                    'label' => 'Y',
                    'unit' => 'פיקסלים',
                ],
            ],
            'aspect_ratios' => [

                'label' => 'יחסי ציר',

                'no_fixed' => [
                    'label' => 'חופשי',
                ],

            ],

        ],
    ],

    'key_value' => [

        'actions' => [

            'add' => [
                'label' => 'הוסף שורה',
            ],

            'delete' => [
                'label' => 'מחק שורה',
            ],

            'reorder' => [
                'label' => 'סדר רשומה מחדש',
            ],

        ],

        'fields' => [

            'key' => [
                'label' => 'שדה',
            ],

            'value' => [
                'label' => 'ערך',
            ],

        ],

    ],

    'markdown_editor' => [

        'toolbar_buttons' => [
            'attach_files' => 'הוסף קבצים',
            'blockquote' => 'בלוק ציטוט',
            'bold' => 'מודגש',
            'bullet_list' => 'רשימת נקודות',
            'code_block' => 'בלוק קוד',
            'heading' => 'כותרת',
            'italic' => 'נטוי',
            'link' => 'קישור',
            'ordered_list' => 'רשימה ממוספרת',
            'strike' => 'כתיב מחדל',
            'redo' => 'שחזור',
            'table' => 'טבלה',
            'undo' => 'ביטול שחזור',
        ],

    ],

    'repeater' => [

        'actions' => [

            'add' => [
                'label' => 'הוסף ל :label',
            ],

            'delete' => [
                'label' => 'מחק',
            ],

            'clone' => [
                'label' => 'שכפל',
            ],

            'reorder' => [
                'label' => 'העבר',
            ],

            'move_down' => [
                'label' => 'הזז מטה',
            ],

            'move_up' => [
                'label' => 'הזז מעלה',
            ],

            'collapse' => [
                'label' => 'צמצם',
            ],

            'expand' => [
                'label' => 'הרחב',
            ],

            'collapse_all' => [
                'label' => 'צמצם הכל',
            ],

            'expand_all' => [
                'label' => 'הרחב הכל',
            ],

        ],

    ],

    'rich_editor' => [

        'dialogs' => [

            'link' => [

                'actions' => [
                    'link' => 'קישור',
                    'unlink' => 'בטל קישור',
                ],

                'label' => 'כתובת',

                'placeholder' => 'הכנס כתובת',

            ],

        ],

        'toolbar_buttons' => [
            'attach_files' => 'הוסף קבצים',
            'blockquote' => 'בלוק ציטוט',
            'bold' => 'מודגש',
            'bullet_list' => 'רשימת נקודות',
            'code_block' => 'בלוק קוד',
            'h1' => 'כותרת 1',
            'h2' => 'כותרת 2',
            'h3' => 'כותרת 3',
            'italic' => 'נטוי',
            'link' => 'קישור',
            'ordered_list' => 'רשימה ממוספרת',
            'redo' => 'חזור על',
            'strike' => 'כתיב מחדל',
            'underline' => 'קו תחתון',
            'undo' => 'בטל',
        ],

    ],

    'select' => [

        'actions' => [

            'create_option' => [

                'modal' => [

                    'heading' => 'יצירה',

                    'actions' => [

                        'create' => [
                            'label' => 'צור',
                        ],
                        'create_another' => [
                            'label' => 'צור וצור עוד אחת',
                        ],

                    ],

                ],

            ],

            'edit_option' => [

                'modal' => [

                    'heading' => 'עריכה',

                    'actions' => [

                        'save' => [
                            'label' => 'שמור',
                        ],

                    ],

                ],

            ],

        ],

        'boolean' => [
            'true' => 'כן',
            'false' => 'לא',
        ],

        'loading_message' => 'טוען...',

        'max_items_message' => 'ניתן לבחור רק :count',

        'no_search_results_message' => 'לא נמצאו תוצאות.',

        'placeholder' => 'בחר',

        'searching_message' => 'מחפש...',

        'search_prompt' => 'התחל להקליד על מנת לחפש...',

    ],

    'tags_input' => [
        'placeholder' => 'תגית חדשה',
    ],

    'wizard' => [

        'actions' => [

            'previous_step' => [
                'label' => 'הקודם',
            ],

            'next_step' => [
                'label' => 'הבא',
            ],

        ],

    ],

];
