<?php

return [

    'confirmation' => 'Bạn có chắc chắn khi thực hiện thao tác này?',

    'actions' => [

        'cancel' => [
            'label' => 'Huỷ bỏ',
        ],

        'confirm' => [
            'label' => 'Xác nhận',
        ],

        'submit' => [
            'label' => 'Gửi',
        ],

    ],

];
