<?php

return [

    'title' => 'Վերականգնել Ձեր գաղտնաբառը',

    'heading' => 'Մոռացե՞լ եք գաղտնաբառը',

    'actions' => [

        'login' => [
            'label' => 'Վերադառնալ դեպի մուտք',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'Էլ. փոստի հասցե',
        ],

        'actions' => [

            'request' => [
                'label' => 'Ուղարկել էլ. նամակ',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'Չափից շատ հարցումներ',
            'body' => 'Խնդրում ենք :seconds վայրկյան անց կրկին փորձել։',
        ],

    ],

];
