<?php

return [

    'confirmation' => 'Сигурен ли си, че искаш да направиш това?',

    'actions' => [

        'cancel' => [
            'label' => 'Откажи',
        ],

        'confirm' => [
            'label' => 'Потвърди',
        ],

        'submit' => [
            'label' => 'Изпрати',
        ],

    ],

];
