<?php

return [

    'title' => 'Σύνδεση',

    'heading' => 'Συνδεθείτε στο λογαριασμό σας',

    'actions' => [

        'register' => [
            'before' => 'ή',
            'label' => 'αιτηθείτε για έναν νέο λογαριασμό',
        ],

        'request_password_reset' => [
            'label' => 'Ξεχάσατε τον κωδικό σας;',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'Διεύθυνση ηλεκτρονικού ταχυδρομείου',
        ],

        'password' => [
            'label' => 'Κωδικός πρόσβασης',
        ],

        'remember' => [
            'label' => 'Θυμήσου με',
        ],

        'actions' => [

            'authenticate' => [
                'label' => 'Συνδεθείτε',
            ],

        ],

    ],

    'messages' => [

        'failed' => 'Τα στοιχεία που δώσατε δεν συνδέονται με λογαριασμό.',

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'Πάρα πολλές προσπάθειες σύνδεσης. Δοκιμάστε ξανά μετά από :seconds δευτερόλεπτα.',
            'body' => 'Παρακαλούμε δοκιμάστε πάλι σε :seconds δευτερόλεπτα.',
        ],

    ],

];
