<?php

return [

    'builder' => [

        'actions' => [

            'clone' => [
                'label' => 'Kloniraj',
            ],

            'add' => [
                'label' => 'Dodaj :label',
            ],

            'add_between' => [
                'label' => 'Ubaci',
            ],

            'delete' => [
                'label' => 'Izbriši',
            ],

            'reorder' => [
                'label' => 'Pomjeri',
            ],

            'move_down' => [
                'label' => 'Dolje',
            ],

            'move_up' => [
                'label' => 'Gore',
            ],

            'collapse' => [
                'label' => 'Sažimanje',
            ],

            'expand' => [
                'label' => 'Proširivanje',
            ],

            'collapse_all' => [
                'label' => 'Sažmi sve',
            ],

            'expand_all' => [
                'label' => 'Proširi sve',
            ],

        ],

    ],

    'checkbox_list' => [

        'actions' => [

            'deselect_all' => [
                'label' => 'Odznači sve',
            ],

            'select_all' => [
                'label' => 'Označi sve',
            ],

        ],

    ],

    'key_value' => [

        'actions' => [

            'add' => [
                'label' => 'Dodaj red',
            ],

            'delete' => [
                'label' => 'Izbriši red',
            ],

            'reorder' => [
                'label' => 'Preuredi red',
            ],

        ],

        'fields' => [

            'key' => [
                'label' => 'Ključ',
            ],

            'value' => [
                'label' => 'Vrijednost',
            ],

        ],

    ],

    'markdown_editor' => [

        'toolbar_buttons' => [
            'attach_files' => 'Priloži fajlove',
            'bold' => 'Bold',
            'bullet_list' => 'Bullet list',
            'code_block' => 'Blok koda',
            'edit' => 'Uredi',
            'italic' => 'Kurziv',
            'link' => 'Link',
            'ordered_list' => 'Numerisana lista',
            'preview' => 'Prethodan pregled',
            'strike' => 'Precrtano',
        ],

    ],

    'repeater' => [

        'actions' => [

            'add' => [
                'label' => 'Dodaj :label',
            ],

            'delete' => [
                'label' => 'Izbriši',
            ],

            'clone' => [
                'label' => 'Kloniraj',
            ],

            'reorder' => [
                'label' => 'Pomjeriti',
            ],

            'move_down' => [
                'label' => 'Dolje',
            ],

            'move_up' => [
                'label' => 'Gore',
            ],

            'collapse' => [
                'label' => 'Sažimanje',
            ],

            'expand' => [
                'label' => 'Proširivanje',
            ],

            'collapse_all' => [
                'label' => 'Sažmi sve',
            ],

            'expand_all' => [
                'label' => 'Proširi sve',
            ],

        ],

    ],

    'rich_editor' => [

        'dialogs' => [

            'link' => [

                'actions' => [
                    'link' => 'Link',
                    'unlink' => 'Otkačite link',
                ],

                'label' => 'URL',

                'placeholder' => 'Unesite URL',

            ],

        ],

        'toolbar_buttons' => [
            'attach_files' => 'Priloži fajlove',
            'blockquote' => 'Blok citat',
            'bold' => 'Bold',
            'bullet_list' => 'Bullet list',
            'code_block' => 'Blok koda',
            'h1' => 'Titula',
            'h2' => 'Naslov',
            'h3' => 'Podnaslov',
            'italic' => 'Kurziv',
            'link' => 'Link',
            'ordered_list' => 'Numerisana lista',
            'redo' => 'Ponovo uradite',
            'strike' => 'Precrtano',
            'undo' => 'Poništi',
        ],

    ],

    'select' => [

        'actions' => [

            'create_option' => [

                'modal' => [

                    'heading' => 'Napravi',

                    'actions' => [

                        'create' => [
                            'label' => 'Napravi',
                        ],

                    ],

                ],

            ],

        ],

        'boolean' => [
            'true' => 'Da',
            'false' => 'Ne',
        ],

        'loading_message' => 'Učitavanje ...',

        'max_items_message' => 'Mogu se odabrati samo :count.',

        'no_search_results_message' => 'Nijedna opcija ne odgovara vašoj pretrazi.',

        'placeholder' => 'Izaberi opciju',

        'searching_message' => 'Traženje ...',

        'search_prompt' => 'Počni da kucate da biste pretraživali ...',

    ],

    'tags_input' => [
        'placeholder' => 'Nova oznaka',
    ],

    'wizard' => [

        'actions' => [

            'previous_step' => [
                'label' => 'Nazad',
            ],

            'next_step' => [
                'label' => 'Dalje',
            ],

        ],

    ],

];
