<x-filament-actions::group
    :badge="$getBadge()"
    :badge-color="$getBadgeColor()"
    dynamic-component="filament::icon-button"
    :group="$group"
    :label="$getLabel()"
    :size="$getSize()"
    class="fi-ac-icon-btn-group"
/>
