<?php

return [

    'single' => [

        'label' => 'Izbrišite',

        'modal' => [

            'heading' => 'Brisanje :label',

            'actions' => [

                'delete' => [
                    'label' => 'Izbrisati',
                ],

            ],

        ],

        'notifications' => [

            'deleted' => [
                'title' => 'Izbrisano',
            ],

        ],

    ],

    'multiple' => [

        'label' => 'Izbrišite izabrano',

        'modal' => [

            'heading' => 'Izbrišite izabrani :label ',

            'actions' => [

                'delete' => [
                    'label' => 'Izbrišite izabrani',
                ],

            ],

        ],

        'notifications' => [

            'deleted' => [
                'title' => 'Izbrisano',
            ],

        ],

    ],

];
