<?php

return [

    'label' => 'Hồ sơ',

    'form' => [

        'email' => [
            'label' => 'Địa chỉ email',
        ],

        'name' => [
            'label' => 'Họ tên',
        ],

        'password' => [
            'label' => 'Mật khẩu mới',
        ],

        'password_confirmation' => [
            'label' => 'Xác nhận mật khẩu mới',
        ],

        'actions' => [

            'save' => [
                'label' => 'Lưu thay đổi',
            ],

        ],

    ],

    'notifications' => [

        'saved' => [
            'title' => 'Đã lưu',
        ],

    ],

    'actions' => [

        'cancel' => [
            'label' => 'quay lại',
        ],

    ],

];
