<?php

return [

    'single' => [

        'label' => 'Forza eliminazione',

        'modal' => [

            'heading' => 'Forza eliminazione :label',

            'actions' => [

                'delete' => [
                    'label' => 'Elimina',
                ],

            ],

        ],

        'notifications' => [

            'deleted' => [
                'title' => 'Eliminato',
            ],

        ],

    ],

    'multiple' => [

        'label' => 'Elimina forzatamente selezionati',

        'modal' => [

            'heading' => 'Elimina forzatamente :label selezionati',

            'actions' => [

                'delete' => [
                    'label' => 'Elimina',
                ],

            ],

        ],

        'notifications' => [

            'deleted' => [
                'title' => 'Eliminati',
            ],

        ],

    ],

];
