<?php

return [

    'title' => 'Скинути пароль',

    'heading' => 'Забули свій пароль?',

    'actions' => [

        'login' => [
            'label' => 'повернутись до сторінки входу',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'Електронна пошта',
        ],

        'actions' => [

            'request' => [
                'label' => 'Надіслати лист',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'Забагато запитів',
            'body' => 'Будь ласка, спробуйте ще раз через :seconds секунд.',
        ],

    ],

];
