<?php

return [

    'direction' => 'ltr',

    'actions' => [

        'logout' => [
            'label' => 'Toka',
        ],

        'open_database_notifications' => [
            'label' => 'Fungua arifa',
        ],

        'open_user_menu' => [
            'label' => 'Menyu ya Mtumiaji',
        ],

        'theme_switcher' => [

            'dark' => [
                'label' => 'Geuza hali ya giza',
            ],

            'light' => [
                'label' => 'Geuza hali ya mwanga',
            ],

        ],

    ],

];
