<?php

return [

    'confirmation' => 'क्या आप वाकई ऐसा करना चाहेंगे?',

    'actions' => [

        'cancel' => [
            'label' => 'रद्द करें',
        ],

        'confirm' => [
            'label' => 'पुष्टि करें',
        ],

        'submit' => [
            'label' => 'सबमिट',
        ],

    ],

];
