<?php

return [

    'direction' => 'ltr',

    'actions' => [

        'billing' => [
            'label' => '구독 관리',
        ],

        'logout' => [
            'label' => '로그아웃',
        ],

        'open_database_notifications' => [
            'label' => '알림 열기',
        ],

        'open_user_menu' => [
            'label' => '사용자 메뉴',
        ],

        'sidebar' => [

            'collapse' => [
                'label' => '사이드바 접기',
            ],

            'expand' => [
                'label' => '사이드바 펼치기',
            ],

        ],

        'theme_switcher' => [

            'dark' => [
                'label' => '다크 모드',
            ],

            'light' => [
                'label' => '라이트 모드',
            ],

            'system' => [
                'label' => '시스템 테마 사용',
            ],

        ],

    ],

    'avatar' => [
        'alt' => ':name 아바타',
    ],

    'logo' => [
        'alt' => ':name 로고',
    ],

];
