<?php

return [

    'direction' => 'ltr',

    'actions' => [

        'billing' => [
            'label' => 'Pārvaldīt abonementu',
        ],

        'logout' => [
            'label' => 'Iziet',
        ],

        'open_database_notifications' => [
            'label' => 'Atvērt paziņojumus',
        ],

        'open_user_menu' => [
            'label' => 'Lietotāja izvēlne',
        ],

        'sidebar' => [

            'collapse' => [
                'label' => 'Sakļaut sānjoslu',
            ],

            'expand' => [
                'label' => 'Izvērst sānjoslu',
            ],

        ],

        'theme_switcher' => [

            'dark' => [
                'label' => 'Pārslēgt uz tumšo režīmu',
            ],

            'light' => [
                'label' => 'Pārslēgt uz gaišo režīmu',
            ],

            'system' => [
                'label' => 'Pārslēgt uz sistēmas režīmu',
            ],

        ],

    ],

];
