<?php

namespace Filament\Tables\Columns\Concerns;

use Filament\Support\Concerns\HasExtraAttributes as BaseTrait;

/**
 * @deprecated Use `\Filament\Support\Concerns\HasExtraAttributes` instead.
 * @see Action
 */
trait HasExtraAttributes
{
    use BaseTrait;
}
