<?php

return [

    'label' => '프로필',

    'form' => [

        'email' => [
            'label' => '이메일',
        ],

        'name' => [
            'label' => '이름',
        ],

        'password' => [
            'label' => '새 비밀번호',
        ],

        'password_confirmation' => [
            'label' => '새 비밀번호 확인',
        ],

        'actions' => [

            'save' => [
                'label' => '변경 사항 저장',
            ],

        ],

    ],

    'notifications' => [

        'saved' => [
            'title' => '저장 완료',
        ],

    ],

    'actions' => [

        'cancel' => [
            'label' => '취소',
        ],

    ],

];
