<?php

return [

    'label' => 'הצגת רשומות',

    'overview' => 'מציג :first - :last מתוך :total תוצאות',

    'fields' => [

        'records_per_page' => [

            'label' => 'בעמוד',

            'options' => [
                'all' => 'הכל',
            ],

        ],

    ],

    'actions' => [

        'go_to_page' => [
            'label' => 'נווט לעמוד :page',
        ],

        'next' => [
            'label' => 'הבא',
        ],

        'previous' => [
            'label' => 'הקודם',
        ],

    ],

];
