<?php

return [

    'confirmation' => 'هل أنت متأكد من القيام بهذه العملية؟',

    'actions' => [

        'cancel' => [
            'label' => 'إلغاء',
        ],

        'confirm' => [
            'label' => 'تأكيد',
        ],

        'submit' => [
            'label' => 'إرسال',
        ],

    ],

];
