<?php

return [

    'direction' => 'ltr',

    'actions' => [

        'billing' => [
            'label' => 'Menaxho abonimin',
        ],

        'logout' => [
            'label' => 'Dil',
        ],

        'open_database_notifications' => [
            'label' => 'Hap njoftimet',
        ],

        'open_user_menu' => [
            'label' => 'Menuja e përdoruesit',
        ],

        'sidebar' => [

            'collapse' => [
                'label' => 'Mbyll menunë',
            ],

            'expand' => [
                'label' => 'Hap menunë',
            ],

        ],

        'theme_switcher' => [

            'dark' => [
                'label' => 'Aktivizo template-in e errët',
            ],

            'light' => [
                'label' => 'Aktivizo template-in e shndritshëm',
            ],

            'system' => [
                'label' => 'Aktivizo template-in e sistemit',
            ],

        ],

    ],

];
