<?php

return [

    'single' => [

        'label' => 'Geri yükle',

        'modal' => [

            'heading' => ':label geri yükle',

            'actions' => [

                'restore' => [
                    'label' => 'Geri yükle',
                ],

            ],

        ],

        'notifications' => [

            'restored' => [
                'title' => 'Kayıt geri yüklendi',
            ],

        ],

    ],

    'multiple' => [

        'label' => 'Seçiliyi geri yükle',

        'modal' => [

            'heading' => ':label seçiliyi geri yükle',

            'actions' => [

                'restore' => [
                    'label' => 'Geri yükle',
                ],

            ],

        ],

        'notifications' => [

            'restored' => [
                'title' => 'Kayıtlar geri yüklendi',
            ],

        ],

    ],

];
