<?php

return [

    'label' => 'पृष्ठ मार्गदर्शन',

    'overview' => ':first से :last प्रविष्टियां :total में से',

    'fields' => [

        'records_per_page' => [
            'label' => 'प्रति पृष्ठ',
        ],

    ],

    'actions' => [

        'go_to_page' => [
            'label' => 'पृष्ठ :page पर जाएं',
        ],

        'next' => [
            'label' => 'अगला',
        ],

        'previous' => [
            'label' => 'पिछला',
        ],

    ],

];
