<?php

return [

    'title' => 'Paroles maiņa',

    'heading' => 'Aizmirsāt paroli?',

    'actions' => [

        'login' => [
            'label' => 'atpakaļ uz pieteikšanās lapu',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'E-pasta adrese',
        ],

        'actions' => [

            'request' => [
                'label' => 'Sūtīt e-pastu',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'Pārāk daudz mēģinājumu',
            'body' => 'Lūdzu, mēģiniet vēlreiz pēc :seconds sekundēm.',
        ],

    ],

];
