<?php

namespace Filament\Pages\Actions;

use Filament\Actions\SelectAction as BaseAction;

/**
 * @deprecated Use `\Filament\Actions\SelectAction` instead.
 */
class SelectAction extends BaseAction {}
