<?php

namespace Filament\Forms\Components\Concerns;

use Filament\Support\Concerns\HasExtraAttributes as BaseTrait;

/**
 * @deprecated Use `\Filament\Support\Concerns\HasExtraAttributes` instead.
 * @see BaseTrait
 */
trait HasExtraAttributes
{
    use BaseTrait;
}
