<?php

return [

    'confirmation' => 'แน่ใจหรือไม่ว่าต้องการดำเนินการต่อ',

    'actions' => [

        'cancel' => [
            'label' => 'ยกเลิก',
        ],

        'confirm' => [
            'label' => 'ยืนยัน',
        ],

        'submit' => [
            'label' => 'ส่ง',
        ],

    ],

];
