<?php

namespace Filament\Support\Enums;

enum FontWeight
{
    case Thin;

    case ExtraLight;

    case Light;

    case Normal;

    case Medium;

    case SemiBold;

    case Bold;

    case ExtraBold;

    case Black;
}
