<?php

return [

    'builder' => [

        'actions' => [

            'clone' => [
                'label' => 'Klonatu',
            ],

            'add' => [
                'label' => 'Gehitu :label',
            ],

            'add_between' => [
                'label' => 'Txertatu',
            ],

            'delete' => [
                'label' => 'Ezabatu',
            ],

            'reorder' => [
                'label' => 'Mugitu',
            ],

            'move_down' => [
                'label' => 'Jaitsi',
            ],

            'move_up' => [
                'label' => 'Igo',
            ],

            'collapse' => [
                'label' => 'Kontrairatu',
            ],

            'expand' => [
                'label' => 'Zabaldu',
            ],

            'collapse_all' => [
                'label' => 'Kontrairatu dena',
            ],

            'expand_all' => [
                'label' => 'Zabaldu dena',
            ],

        ],

    ],

    'checkbox_list' => [

        'actions' => [

            'deselect_all' => [
                'label' => 'Deselektatu guztia',
            ],

            'select_all' => [
                'label' => 'Aukeratu guztia',
            ],

        ],

    ],

    'key_value' => [

        'actions' => [

            'add' => [
                'label' => 'Gehitu errenkada',
            ],

            'delete' => [
                'label' => 'Ezabatu errenkada',
            ],

            'reorder' => [
                'label' => 'Birordenatu errenkada',
            ],

        ],

        'fields' => [

            'key' => [
                'label' => 'Giltza',
            ],

            'value' => [
                'label' => 'Balioa',
            ],

        ],

    ],

    'markdown_editor' => [

        'toolbar_buttons' => [
            'attach_files' => 'Erantsi agiriak',
            'blockquote' => 'Aipuak',
            'bold' => 'Lodia',
            'bullet_list' => 'Buletinak',
            'code_block' => 'Kode-blokea',
            'heading' => 'Goiburua',
            'edit' => 'Idatzi',
            'italic' => 'Etzana',
            'link' => 'Esteka',
            'ordered_list' => 'Zerrenda zenbakiduna',
            'preview' => 'Aurreikuspena',
            'strike' => 'Marratua',
            'redo' => 'Berregin',
            'table' => 'Taula',
            'undo' => 'Desegin',
        ],

    ],

    'repeater' => [

        'actions' => [

            'add' => [
                'label' => 'Gehitu :label',
            ],

            'delete' => [
                'label' => 'Ezabatu',
            ],

            'reorder' => [
                'label' => 'Mugitu',
            ],

            'clone' => [
                'label' => 'Klonatu',
            ],

            'move_down' => [
                'label' => 'Jaitsi',
            ],

            'move_up' => [
                'label' => 'Igo',
            ],

            'collapse' => [
                'label' => 'Kontrairatu',
            ],

            'expand' => [
                'label' => 'Zabaldu',
            ],

            'collapse_all' => [
                'label' => 'Kontrairatu dena',
            ],

            'expand_all' => [
                'label' => 'Zabaldu dena',
            ],

        ],

    ],

    'rich_editor' => [

        'dialogs' => [

            'link' => [

                'actions' => [
                    'link' => 'Esteka',
                    'unlink' => 'Kendu esteka',
                ],

                'label' => 'URL',

                'placeholder' => 'Idatzi URL estekatzeko',

            ],

        ],

        'toolbar_buttons' => [
            'attach_files' => 'Erantsi agiriak',
            'blockquote' => 'Aipuak',
            'bold' => 'Lodia',
            'bullet_list' => 'Buletinak',
            'code_block' => 'Kode-blokea',
            'h1' => 'Izenburua',
            'h2' => 'Goiburua',
            'h3' => 'Azpigoiburua',
            'italic' => 'Etzana',
            'link' => 'Esteka',
            'ordered_list' => 'Zerrenda zenbakiduna',
            'redo' => 'Berregin',
            'strike' => 'Marratua',
            'underline' => 'Azpimarratua',
            'undo' => 'Desegin',
        ],

    ],

    'select' => [

        'actions' => [

            'create_option' => [

                'modal' => [

                    'heading' => 'Berria',

                    'actions' => [

                        'create' => [
                            'label' => 'Sortu',
                        ],
                        'create_another' => [
                            'label' => 'Sortu eta beste bat',
                        ],

                    ],

                ],

            ],

            'edit_option' => [

                'modal' => [

                    'heading' => 'Editatu',

                    'actions' => [

                        'save' => [
                            'label' => 'Gorde',
                        ],

                    ],

                ],

            ],

        ],

        'boolean' => [
            'true' => 'Bai',
            'false' => 'Ez',
        ],

        'loading_message' => 'Kargatzen...',
        'max_items_message' => 'Soilik :count hauta daiteke.',
        'no_search_results_message' => 'Ez da bat datorren bilaketarekin.',
        'placeholder' => 'Aukeratu aukera bat',
        'searching_message' => 'Bilatzen...',

        'search_prompt' => 'Idatzi bilatzeko...',
    ],

    'tags_input' => [
        'placeholder' => 'Etiketa berria',
    ],

    'wizard' => [

        'actions' => [

            'previous_step' => [
                'label' => 'Aurrekoa',
            ],

            'next_step' => [
                'label' => 'Hurrengoa',
            ],

        ],

    ],

];
