<?php

return [

    'title' => 'استعادة كلمة المرور',

    'heading' => 'نسيت كلمة المرور؟',

    'actions' => [

        'login' => [
            'label' => 'العودة لتسجيل الدخول',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'البريد الإلكتروني',
        ],

        'actions' => [

            'request' => [
                'label' => 'أرسل البريد الإلكتروني',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'لقد قمت بمحاولات كثيرة جداً',
            'body' => 'يرجى المحاولة مرة أخرى بعد :seconds ثواني.',
        ],

    ],

];
