<?php

return [

    'title' => 'Επαναφορά κωδικού',

    'heading' => 'Ξεχάσατε τον κωδικό σας?',

    'actions' => [

        'login' => [
            'label' => 'back to login',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'Διεύθυνση Email',
        ],

        'actions' => [

            'request' => [
                'label' => 'Αποστολή email',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'Πάρα πολλά αιτήματα',
            'body' => 'Παρακαλούμε δοκιμάστε πάλι σε :seconds δευτερόλεπτα.',
        ],

    ],

];
