<?php

return [

    'single' => [

        'label' => '復旧',

        'modal' => [

            'heading' => ':label 復旧',

            'actions' => [

                'restore' => [
                    'label' => '復旧',
                ],

            ],

        ],

        'notifications' => [

            'restored' => [
                'title' => '復旧しました',
            ],

        ],

    ],

    'multiple' => [

        'label' => '選択中を復旧',

        'modal' => [

            'heading' => '選択中の:labelを復旧',

            'actions' => [

                'restore' => [
                    'label' => '復旧',
                ],

            ],

        ],

        'notifications' => [

            'restored' => [
                'title' => '復旧しました',
            ],

        ],

    ],

];
