<?php

namespace Filament\Pages\Actions;

use Filament\Actions\RestoreAction as BaseAction;

/**
 * @deprecated Use `\Filament\Actions\RestoreAction` instead.
 */
class RestoreAction extends BaseAction {}
