<?php

return [

    'confirmation' => 'Jste si jistí touto akcí?',

    'actions' => [

        'cancel' => [
            'label' => 'Zrušit',
        ],

        'confirm' => [
            'label' => 'Potvrdit',
        ],

        'submit' => [
            'label' => 'Odeslat',
        ],

    ],

];
