<?php

return [

    'direction' => 'ltr',

    'actions' => [

        'billing' => [
            'label' => '管理订阅',
        ],

        'logout' => [
            'label' => '退出登录',
        ],

        'open_database_notifications' => [
            'label' => '打开通知',
        ],

        'open_user_menu' => [
            'label' => '用户菜单',
        ],

        'sidebar' => [

            'collapse' => [
                'label' => '折叠侧边栏',
            ],

            'expand' => [
                'label' => '展开侧边栏',
            ],

        ],

        'theme_switcher' => [

            'dark' => [
                'label' => '切换至深色主题',
            ],

            'light' => [
                'label' => '切换至浅色主题',
            ],

            'system' => [
                'label' => '按照系统主题切换',
            ],

        ],

    ],

];
