<?php

return [

    'title' => 'Resetiraj svoju lozinku',

    'heading' => 'Zaboravljena lozinka?',

    'actions' => [

        'login' => [
            'label' => 'natrag na prijavu',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'Adresa e-pošte',
        ],

        'actions' => [

            'request' => [
                'label' => 'Pošalji e-poštu',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'Previše zahtjeva',
            'body' => 'Molim te, pokušaj ponovno za :seconds sekundi.',
        ],

    ],

];
