<?php

namespace Filament\Tables\Enums;

enum FiltersLayout
{
    case AboveContent;

    case AboveContentCollapsible;

    case BelowContent;

    case Dropdown;

    case Modal;

    case Hidden;
}
