<?php

return [

    'direction' => 'ltr',

    'actions' => [

        'billing' => [
            'label' => 'サブスクリプションを管理',
        ],

        'logout' => [
            'label' => 'ログアウト',
        ],

        'open_database_notifications' => [
            'label' => 'お知らせを確認',
        ],

        'open_user_menu' => [
            'label' => 'ユーザーメニュー',
        ],

        'sidebar' => [

            'collapse' => [
                'label' => 'サイドバーを折り畳む',
            ],

            'expand' => [
                'label' => 'サイドバーを展開する',
            ],

        ],

        'theme_switcher' => [

            'dark' => [
                'label' => 'ダークモードに切り替える',
            ],

            'light' => [
                'label' => 'ライトモードに切り替える',
            ],

            'system' => [
                'label' => 'システムテーマを有効にする',
            ],

        ],

    ],

    'avatar' => [
        'alt' => ':nameのアバター',
    ],

    'logo' => [
        'alt' => ':nameロゴ',
    ],

];
