<?php

return [

    'direction' => 'ltr',

    'actions' => [

        'billing' => [
            'label' => 'Gerenciar assinatura',
        ],

        'logout' => [
            'label' => 'Logout',
        ],

        'open_database_notifications' => [
            'label' => 'Abrir notificações',
        ],

        'open_user_menu' => [
            'label' => 'Menu do usuário',
        ],

        'sidebar' => [

            'collapse' => [
                'label' => 'Recolher barra lateral',
            ],

            'expand' => [
                'label' => 'Expandir barra lateral',
            ],

        ],

        'theme_switcher' => [

            'dark' => [
                'label' => 'Mudar para tema escuro',
            ],

            'light' => [
                'label' => 'Mudar para tema claro',
            ],

            'system' => [
                'label' => 'Mudar para tema do sistema',
            ],

        ],

    ],

    'avatar' => [
        'alt' => 'Avatar de :name',
    ],

    'logo' => [
        'alt' => ':name (Logotipo)',
    ],

];
