<?php

return [

    'direction' => 'ltr',

    'actions' => [

        'billing' => [
            'label' => 'Quản lý gói đăng ký',
        ],

        'logout' => [
            'label' => 'Đăng xuất',
        ],

        'open_database_notifications' => [
            'label' => 'Mở thông báo',
        ],

        'open_user_menu' => [
            'label' => 'Menu người dùng',
        ],

        'sidebar' => [

            'collapse' => [
                'label' => 'Thu gọn thanh bên',
            ],

            'expand' => [
                'label' => 'Mở rộng thanh bên',
            ],

        ],

        'theme_switcher' => [

            'dark' => [
                'label' => 'Bật chế độ tối',
            ],

            'light' => [
                'label' => 'Bật chế độ sáng',
            ],

            'system' => [
                'label' => 'Bật chế độ hệ thống',
            ],

        ],

    ],

    'avatar' => [
        'alt' => 'Ảnh đại diện của :name',
    ],

    'logo' => [
        'alt' => 'Logo :name',
    ],

];
