<?php

namespace Filament\Tables\View;

class TablesRenderHook
{
    const SELECTION_INDICATOR_ACTIONS_AFTER = 'tables::selection.indicator.actions.after';

    const SELECTION_INDICATOR_ACTIONS_BEFORE = 'tables::selection.indicator.actions.before';

    const HEADER_AFTER = 'tables::header.after';

    const HEADER_BEFORE = 'tables::header.before';

    const TOOLBAR_AFTER = 'tables::toolbar.after';

    const TOOLBAR_BEFORE = 'tables::toolbar.before';

    const TOOLBAR_END = 'tables::toolbar.end';

    const TOOLBAR_GROUPING_SELECTOR_AFTER = 'tables::toolbar.grouping-selector.after';

    const TOOLBAR_GROUPING_SELECTOR_BEFORE = 'tables::toolbar.grouping-selector.before';

    const TOOLBAR_REORDER_TRIGGER_AFTER = 'tables::toolbar.reorder-trigger.after';

    const TOOLBAR_REORDER_TRIGGER_BEFORE = 'tables::toolbar.reorder-trigger.before';

    const TOOLBAR_SEARCH_AFTER = 'tables::toolbar.search.after';

    const TOOLBAR_SEARCH_BEFORE = 'tables::toolbar.search.before';

    const TOOLBAR_START = 'tables::toolbar.start';

    const TOOLBAR_TOGGLE_COLUMN_TRIGGER_AFTER = 'tables::toolbar.toggle-column-trigger.after';

    const TOOLBAR_TOGGLE_COLUMN_TRIGGER_BEFORE = 'tables::toolbar.toggle-column-trigger.before';
}
