<?php

return [

    'confirmation' => 'Jeni të sigurt që dëshironi ta bëni këtë?',

    'actions' => [

        'cancel' => [
            'label' => 'Anulo',
        ],

        'confirm' => [
            'label' => 'Konfirmo',
        ],

        'submit' => [
            'label' => 'Ruaj',
        ],

    ],

];
