<?php

return [

    'single' => [

        'label' => 'Հարկադրված ջնջել',

        'modal' => [

            'heading' => 'Հարկադրված ջնջել :labelը',

            'actions' => [

                'delete' => [
                    'label' => 'Ջնջել',
                ],

            ],

        ],

        'notifications' => [

            'deleted' => [
                'title' => 'Գրառումը ջնջվել է',
            ],

        ],

    ],

    'multiple' => [

        'label' => 'Հարկադրված ջնջել ընտրվածը',

        'modal' => [

            'heading' => 'Հարկադրված ջնջել ընտրված :labelը',

            'actions' => [

                'delete' => [
                    'label' => 'Ջնջել',
                ],

            ],

        ],

        'notifications' => [

            'deleted' => [
                'title' => 'Գրառումները ջնջվել են',
            ],

        ],

    ],

];
