<?php

return [

    'single' => [

        'label' => 'Supprimer',

        'modal' => [

            'heading' => 'Supprimer :label',

            'actions' => [

                'delete' => [
                    'label' => 'Supprimer',
                ],

            ],

        ],

        'notifications' => [

            'deleted' => [
                'title' => 'Supprimé(e)',
            ],

        ],

    ],

    'multiple' => [

        'label' => 'Supprimer la sélection',

        'modal' => [

            'heading' => 'Supprimer la sélection de :label',

            'actions' => [

                'delete' => [
                    'label' => 'Supprimer la sélection',
                ],

            ],

        ],

        'notifications' => [

            'deleted' => [
                'title' => 'Supprimé(e)s',
            ],

        ],

    ],

];
