<?php

return [

    'title' => 'লগইন',

    'heading' => 'আপনার অ্যাকাউন্টে সাইন ইন করুন',

    'form' => [

        'email' => [
            'label' => 'ইমেইল এড্রেস',
        ],

        'password' => [
            'label' => 'পাসওয়ার্ড',
        ],

        'remember' => [
            'label' => 'মনে রাখুন',
        ],

        'actions' => [

            'authenticate' => [
                'label' => 'সাইন ইন',
            ],

        ],

    ],

    'messages' => [

        'failed' => 'আপনার নথি পাওয়া যায় নি।',

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'বহুসংখ্যক চেষ্টা, :seconds সেকেন্ড পরে পুনরায় চেষ্টা করুন।',
        ],

    ],

];
