<?php

return [

    'confirmation' => 'Та үүнийг устгахдаа итгэлтэй байна уу?',

    'actions' => [

        'cancel' => [
            'label' => 'Цуцлах',
        ],

        'confirm' => [
            'label' => 'Баталгаажуулах',
        ],

        'submit' => [
            'label' => 'Батлах',
        ],

    ],

];
