<?php

return [

    'confirmation' => 'האם אתה בטוח?',

    'actions' => [

        'cancel' => [
            'label' => 'ביטול',
        ],

        'confirm' => [
            'label' => 'אישור',
        ],

        'submit' => [
            'label' => 'שלח',
        ],

    ],

];
