<?php

namespace Filament\Pages\Actions;

use Filament\Actions\DeleteAction as BaseAction;

/**
 * @deprecated Use `\Filament\Actions\DeleteAction` instead.
 */
class DeleteAction extends BaseAction {}
