<?php

return [

    'distinct' => [
        'must_be_selected' => 'Ít nhất một trường :attribute phải được chọn.',
        'only_one_must_be_selected' => 'Chỉ có một trường :attribute được chọn.',
    ],

];
