<?php

return [

    'single' => [

        'label' => 'Xóa vĩnh viễn',

        'modal' => [

            'heading' => 'Xóa vĩnh viễn :label',

            'actions' => [

                'delete' => [
                    'label' => 'Xoá',
                ],

            ],

        ],

        'notifications' => [

            'deleted' => [
                'title' => 'Đã xoá',
            ],

        ],

    ],

    'multiple' => [

        'label' => 'Xóa vĩnh viễn các mục đã chọn',

        'modal' => [

            'heading' => 'Xóa vĩnh viễn các mục :label đã chọn',

            'actions' => [

                'delete' => [
                    'label' => 'Xoá',
                ],

            ],

        ],

        'notifications' => [

            'deleted' => [
                'title' => 'Đã xoá',
            ],

        ],

    ],

];
