<?php

namespace Filament\Pages\Actions;

use Filament\Actions\ForceDeleteAction as BaseAction;

/**
 * @deprecated Use `\Filament\Actions\ForceDeleteAction` instead.
 */
class ForceDeleteAction extends BaseAction {}
