<?php

return [

    'title' => 'Şifrənizi Sıfırlayın',

    'heading' => 'Şifrənizi unutmusunuz?',

    'actions' => [

        'login' => [
            'label' => 'girişə geri dön',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'E-poçt ünvanı',
        ],

        'actions' => [

            'request' => [
                'label' => 'E-poçt göndər',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'Bir çox istəmə cəhdi',
            'body' => 'Zəhmət olmazsa :seconds saniyə sonra təkrar yoxlayın.',
        ],

    ],

];
