<?php

return [

    'title' => 'Rediger :label',

    'breadcrumb' => 'Rediger',

    'form' => [

        'actions' => [

            'cancel' => [
                'label' => 'Annuller',
            ],

            'save' => [
                'label' => 'Gem ændringer',
            ],

        ],

    ],

    'content' => [

        'tab' => [
            'label' => 'Rediger',
        ],

    ],

    'notifications' => [

        'saved' => [
            'title' => 'Gemt',
        ],

    ],

];
