<?php

return [

    'confirmation' => '¿Está segura/o de hacer esto?',

    'actions' => [

        'cancel' => [
            'label' => 'Cancelar',
        ],

        'confirm' => [
            'label' => 'Confirmar',
        ],

        'submit' => [
            'label' => 'Enviar',
        ],

    ],

];
