<?php

return [

    'label' => 'Profil',

    'form' => [

        'email' => [
            'label' => 'Alamat emel',
        ],

        'name' => [
            'label' => 'Nama',
        ],

        'password' => [
            'label' => 'Kata laluan baru',
        ],

        'password_confirmation' => [
            'label' => 'Sahkan kata laluan baharu',
        ],

        'actions' => [

            'save' => [
                'label' => 'Simpan perubahan',
            ],

        ],

    ],

    'notifications' => [

        'saved' => [
            'title' => 'Disimpan',
        ],

    ],

    'actions' => [

        'cancel' => [
            'label' => 'ke belakang',
        ],

    ],

];
