<?php

return [

    'builder' => [

        'actions' => [

            'clone' => [
                'label' => 'Klon',
            ],

            'add' => [
                'label' => 'Legge til i :label',
            ],

            'add_between' => [
                'label' => 'Sett inn mellom',
            ],

            'delete' => [
                'label' => 'Slett',
            ],

            'reorder' => [
                'label' => 'Flytt',
            ],

            'move_down' => [
                'label' => 'Flytt ned',
            ],

            'move_up' => [
                'label' => 'Flytt opp',
            ],

            'collapse' => [
                'label' => 'Kollaps',
            ],

            'expand' => [
                'label' => 'Utvid',
            ],

            'collapse_all' => [
                'label' => 'Kollaps alle',
            ],

            'expand_all' => [
                'label' => 'Utvid alle',
            ],

        ],

    ],

    'checkbox_list' => [

        'actions' => [

            'deselect_all' => [
                'label' => 'Fjern alle',
            ],

            'select_all' => [
                'label' => 'Velg alle',
            ],

        ],

    ],

    'file_upload' => [

        'editor' => [

            'actions' => [

                'cancel' => [
                    'label' => 'Avbryt',
                ],

                'drag_crop' => [
                    'label' => 'Dra-modus "beskjær"',
                ],

                'drag_move' => [
                    'label' => 'Dra-modus "flytt"',
                ],

                'flip_horizontal' => [
                    'label' => 'Vend bildet horisontalt',
                ],

                'flip_vertical' => [
                    'label' => 'Vend bildet vertikalt',
                ],

                'move_down' => [
                    'label' => 'Flytt bildet ned',
                ],

                'move_left' => [
                    'label' => 'Flytt vildet til venstre',
                ],

                'move_right' => [
                    'label' => 'Flytt bildet til høyre',
                ],

                'move_up' => [
                    'label' => 'Flytt bildet opp',
                ],

                'reset' => [
                    'label' => 'Nullstill',
                ],

                'rotate_left' => [
                    'label' => 'Roter bildet til venstre',
                ],

                'rotate_right' => [
                    'label' => 'Roter bildet til høyre',
                ],

                'set_aspect_ratio' => [
                    'label' => 'Sett sideforhold til :ratio',
                ],

                'save' => [
                    'label' => 'Lagre',
                ],

                'zoom_100' => [
                    'label' => 'Zoom bildet til 100%',
                ],

                'zoom_in' => [
                    'label' => 'Zoom inn',
                ],

                'zoom_out' => [
                    'label' => 'Zoom ut',
                ],

            ],

            'fields' => [

                'height' => [
                    'label' => 'Høyde',
                    'unit' => 'px',
                ],

                'rotation' => [
                    'label' => 'Rotasjon',
                    'unit' => 'grader',
                ],

                'width' => [
                    'label' => 'Bredde',
                    'unit' => 'px',
                ],

                'x_position' => [
                    'label' => 'X',
                    'unit' => 'px',
                ],

                'y_position' => [
                    'label' => 'Y',
                    'unit' => 'px',
                ],

            ],

            'aspect_ratios' => [

                'label' => 'Sideforhold',

                'no_fixed' => [
                    'label' => 'Fri',
                ],

            ],

            'svg' => [

                'messages' => [
                    'confirmation' => 'Redigering av SVG filer er ikke anbefalt da det kan resultere i tap av kvalitet ved skalering.\n Er du sikker på at du vil fortsette?',
                    'disabled' => 'Redigering av SVG filer er deaktivert da det kan føre til tap av kvalitet ved skalering.',
                ],

            ],

        ],

    ],

    'key_value' => [

        'actions' => [

            'add' => [
                'label' => 'Legg til rad',
            ],

            'delete' => [
                'label' => 'Slett rad',
            ],

            'reorder' => [
                'label' => 'Omorganiser rad',
            ],

        ],

        'fields' => [

            'key' => [
                'label' => 'Nøkkel',
            ],

            'value' => [
                'label' => 'Verdi',
            ],

        ],

    ],

    'markdown_editor' => [

        'toolbar_buttons' => [
            'attach_files' => 'Legg til filer',
            'blockquote' => 'Sitat',
            'bold' => 'Fet',
            'bullet_list' => 'Punktliste',
            'code_block' => 'Kode',
            'heading' => 'Tittel',
            'italic' => 'Kursiv',
            'link' => 'Lenke',
            'ordered_list' => 'Nummerert liste',
            'redo' => 'Gjør om',
            'strike' => 'Gjennomstrekning',
            'table' => 'Tabell',
            'undo' => 'Angre',
        ],

    ],

    'radio' => [

        'boolean' => [
            'true' => 'Ja',
            'false' => 'Nei',
        ],

    ],

    'repeater' => [

        'actions' => [

            'add' => [
                'label' => 'Legg til i :label',
            ],

            'add_between' => [
                'label' => 'Legg til mellom',
            ],

            'delete' => [
                'label' => 'Slett',
            ],

            'clone' => [
                'label' => 'Klon',
            ],

            'reorder' => [
                'label' => 'Flytt',
            ],

            'move_down' => [
                'label' => 'Flytt ned',
            ],

            'move_up' => [
                'label' => 'Flytt opp',
            ],

            'collapse' => [
                'label' => 'Kollaps',
            ],

            'expand' => [
                'label' => 'Utvid',
            ],

            'collapse_all' => [
                'label' => 'Kollaps alle',
            ],

            'expand_all' => [
                'label' => 'Utvid alle',
            ],

        ],

    ],

    'rich_editor' => [

        'dialogs' => [

            'link' => [

                'actions' => [
                    'link' => 'Lenke',
                    'unlink' => 'Fjern lenke',
                ],

                'label' => 'URL',

                'placeholder' => 'Skriv inn URL',

            ],

        ],

        'toolbar_buttons' => [
            'attach_files' => 'Legg til filer',
            'blockquote' => 'Sitat',
            'bold' => 'Fet',
            'bullet_list' => 'Punktliste',
            'code_block' => 'Kode',
            'h1' => 'Tittel',
            'h2' => 'Overskrift',
            'h3' => 'Undertittel',
            'italic' => 'Kursiv',
            'link' => 'Lenke',
            'ordered_list' => 'Nummerert liste',
            'redo' => 'Gjør om',
            'strike' => 'Gjennomstrekning',
            'underline' => 'Understrekning',
            'undo' => 'Angre',
        ],

    ],

    'select' => [

        'actions' => [

            'create_option' => [

                'modal' => [

                    'heading' => 'Opprett',

                    'actions' => [

                        'create' => [
                            'label' => 'Opprett',
                        ],

                        'create_another' => [
                            'label' => 'Opprett & opprett en til',
                        ],

                    ],

                ],

            ],

            'edit_option' => [

                'modal' => [

                    'heading' => 'Endre',

                    'actions' => [

                        'save' => [
                            'label' => 'Lagre',
                        ],

                    ],

                ],

            ],

        ],

        'boolean' => [
            'true' => 'Ja',
            'false' => 'Nei',
        ],

        'loading_message' => 'Laster...',

        'max_items_message' => 'Bare :count kan velges.',

        'no_search_results_message' => 'Ingen alternativer matcher ditt søk.',

        'placeholder' => 'Velg et alternativ',

        'searching_message' => 'Søker...',

        'search_prompt' => 'Skriv for å søke...',

    ],

    'tags_input' => [
        'placeholder' => 'Ny emneknagg',
    ],

    'text_input' => [

        'actions' => [

            'hide_password' => [
                'label' => 'Skjul passord',
            ],

            'show_password' => [
                'label' => 'Vis passord',
            ],

        ],

    ],

    'toggle_buttons' => [

        'boolean' => [
            'true' => 'Ja',
            'false' => 'Nei',
        ],

    ],

    'wizard' => [

        'actions' => [

            'previous_step' => [
                'label' => 'Tilbake',
            ],

            'next_step' => [
                'label' => 'Neste',
            ],

        ],

    ],

];
