<?php

return [

    'confirmation' => 'Are you sure you would like to do this?',

    'actions' => [

        'cancel' => [
            'label' => 'Cancel',
        ],

        'confirm' => [
            'label' => 'Confirm',
        ],

        'submit' => [
            'label' => 'Submit',
        ],

    ],

];
