<?php

return [

    'title' => 'პაროლის აღდგენა',

    'heading' => 'დაგავიწყდა პაროლი?',

    'actions' => [

        'login' => [
            'label' => 'ავტორიზაციის გვერდზე გადასვლა',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'ელფოსტის მისამართი',
        ],

        'actions' => [

            'request' => [
                'label' => 'გაგზავნეთ ელფოსტა',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'ზედმეტად ბევრი მოთხოვნა',
            'body' => 'გთხოვთ, სცადეთ ხელახლა :seconds წამში.',
        ],

    ],

];
