<?php

return [

    'title' => 'Rivendosni fjalëkalimin tuaj',

    'heading' => 'Keni harruar fjalekalimin tuaj?',

    'actions' => [

        'login' => [
            'label' => 'kthehu te identifikohesh',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'Adresa e emailit',
        ],

        'actions' => [

            'request' => [
                'label' => 'Dërgoni një email',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'Shumë kërkesa',
            'body' => 'Ju lutemi provoni përsëri në :seconds sekonda.',
        ],

    ],

];
