<?php

return [

    'title' => 'Elektron pochta manzilingizni tasdiqlang',

    'heading' => 'Hurmatli foydalanuvchi elektron pochta manzilingizni tasdiqlang',

    'actions' => [

        'resend_notification' => [
            'label' => 'Yana bir bor yuborish',
        ],

    ],

    'messages' => [
        'notification_not_received' => 'Biz yuborgan xatni olmadingizmi?',
        'notification_sent' => 'Biz :email manziliga elektron pochta manzilingizni tekshirish bo\'yicha ko\'rsatmalar bilan xat yubordik. Elektron pochtangizni tekshiring',
    ],

    'notifications' => [

        'notification_resent' => [
            'title' => 'Biz elektron pochta xabarini qayta yubordik.',
        ],

        'notification_resend_throttled' => [
            'title' => 'Qayta yuborishlar soni juda koʻp',
            'body' => 'Iltimos, :seconds soniyadan keyin qayta urinib ko\'ring.',
        ],

    ],

];
