<?php

return [

    'modal' => [

        'heading' => 'پیام‌ها',

        'actions' => [

            'clear' => [
                'label' => 'پاک کردن',
            ],

            'mark_all_as_read' => [
                'label' => 'علامت‌گذاری همه به عنوان خوانده‌شده',
            ],

        ],

        'empty' => [
            'heading' => 'شما پیامی ندارید',
            'description' => 'لطفا بعدا مراجعه کنید',
        ],

    ],

];
