<?php

return [

    'title' => 'आफ्नो पासवर्ड रिसेट गर्नुहोस्',

    'heading' => 'तपाईँको पासवर्ड बिर्सनुभयो?',

    'actions' => [

        'login' => [
            'label' => 'लगइन पृष्ठमा फर्कनुहोस्',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'इमेल ठेगाना',
        ],

        'actions' => [

            'request' => [
                'label' => 'इमेल पठाउनुहोस्',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'धेरै अनुरोधहरू',
            'body' => 'कृपया :seconds सेकेन्डमा पुन प्रयास गर्नुहोस्।',
        ],

    ],

];
