<?php

return [

    'title' => 'Հաստատեք Ձեր էլ. փոստի հասցեն',

    'heading' => 'Հաստատեք Ձեր էլ. փոստի հասցեն',

    'actions' => [

        'resend_notification' => [
            'label' => 'Նորից ուղարկել այն',
        ],

    ],

    'messages' => [
        'notification_not_received' => 'Չե՞ք ստացել մեր ուղարկած էլ. նամակը',
        'notification_sent' => 'Մենք նամակ ենք ուղարկել :email էլ. փոստի հասցեին, որը պարունակում է հրահանգներ, թե ինչպես հաստատել Ձեր էլ. փոստը',
    ],

    'notifications' => [

        'notification_resent' => [
            'title' => 'Կրկին էլ. նամակ ենք ուղարկել',
        ],

        'notification_resend_throttled' => [
            'title' => 'Կրկին ուղարկելու չափազանց շատ փորձեր',
            'body' => 'Խնդրում ենք :seconds վայրկյան անց կրկին փորձել։',
        ],

    ],

];
