<?php

return [

    'direction' => 'ltr',

    'actions' => [

        'billing' => [
            'label' => 'Hallitse tilausta',
        ],

        'logout' => [
            'label' => 'Kirjaudu ulos',
        ],

        'open_database_notifications' => [
            'label' => 'Avaa ilmoitukset',
        ],

        'open_user_menu' => [
            'label' => 'Käyttäjävalikko',
        ],

        'sidebar' => [

            'collapse' => [
                'label' => 'Sulje sivupalkki',
            ],

            'expand' => [
                'label' => 'Laajenna sivupalkki',
            ],

        ],

        'theme_switcher' => [

            'dark' => [
                'label' => 'Tumma tila',
            ],

            'light' => [
                'label' => 'Vaalea tila',
            ],

            'system' => [
                'label' => 'Järjestelmän tila',
            ],

        ],

    ],

    'avatar' => [
        'alt' => ':name avatar',
    ],

    'logo' => [
        'alt' => ':name logo',
    ],

];
