<?php

return [

    'builder' => [

        'actions' => [

            'clone' => [
                'label' => 'क्लोन गर्नुहोस्',
            ],

            'add' => [
                'label' => ':label मा थप्नुहोस्',
            ],

            'add_between' => [
                'label' => 'ब्लकहरू बीच सम्मिलित गर्नुहोस्',
            ],

            'delete' => [
                'label' => 'मेटाउनुहोस्',
            ],

            'reorder' => [
                'label' => 'सार्नुहोस्',
            ],

            'move_down' => [
                'label' => 'तल सार्नुहोस्',
            ],

            'move_up' => [
                'label' => 'माथि सार्नुहोस्',
            ],

            'collapse' => [
                'label' => 'संक्षिप्त गर्नुहोस्',
            ],

            'expand' => [
                'label' => 'विस्तार गर्नुहोस्',
            ],

            'collapse_all' => [
                'label' => 'सबै संक्षिप्त गर्नुहोस्',
            ],

            'expand_all' => [
                'label' => 'सबै विस्तार गर्नुहोस्',
            ],

        ],

    ],

    'checkbox_list' => [

        'actions' => [

            'deselect_all' => [
                'label' => 'सबै अचयन गर्नुहोस्',
            ],

            'select_all' => [
                'label' => 'सबै चयन गर्नुहोस्',
            ],

        ],

    ],

    'file_upload' => [

        'editor' => [

            'actions' => [

                'cancel' => [
                    'label' => 'रद्द गर्नुहोस्',
                ],

                'drag_crop' => [
                    'label' => 'तान्ने मोड "क्रप"',
                ],

                'drag_move' => [
                    'label' => 'तान्ने मोड "मुभ"',
                ],

                'flip_horizontal' => [
                    'label' => 'फोटो तेर्सो रूपमा फ्लिप गर्नुहोस्',
                ],

                'flip_vertical' => [
                    'label' => 'फोटो ठाडो रूपमा फ्लिप गर्नुहोस्',
                ],

                'move_down' => [
                    'label' => 'फोटो तल सार्नुहोस्',
                ],

                'move_left' => [
                    'label' => 'फोटोलाई बाँया सार्नुहोस्',
                ],

                'move_right' => [
                    'label' => 'फोटोलाई दायाँ सार्नुहोस्',
                ],

                'move_up' => [
                    'label' => 'फोटो माथि सार्नुहोस्',
                ],

                'reset' => [
                    'label' => 'रिसेट गर्नुहोस्',
                ],

                'rotate_left' => [
                    'label' => 'फोटो बायाँ घुमाउनुहोस्',
                ],

                'rotate_right' => [
                    'label' => 'फोटो दायाँ घुमाउनुहोस्',
                ],

                'set_aspect_ratio' => [
                    'label' => 'पक्ष अनुपात :ratio सेट गर्नुहोस्',
                ],

                'save' => [
                    'label' => 'सुरक्षित गर्नुहोस',
                ],

                'zoom_100' => [
                    'label' => 'फोटोलाई 100% मा जुम गर्नुहोस्',
                ],

                'zoom_in' => [
                    'label' => 'जुम इन गर्नुहोस्',
                ],

                'zoom_out' => [
                    'label' => 'जुम आउट गर्नुहोस्',
                ],

            ],

            'fields' => [

                'height' => [
                    'label' => 'उचाइ',
                    'unit' => 'px',
                ],

                'rotation' => [
                    'label' => 'परिक्रमा',
                    'unit' => 'deg',
                ],

                'width' => [
                    'label' => 'चौडाइ',
                    'unit' => 'px',
                ],

                'x_position' => [
                    'label' => 'X',
                    'unit' => 'px',
                ],

                'y_position' => [
                    'label' => 'Y',
                    'unit' => 'px',
                ],

            ],

            'aspect_ratios' => [

                'label' => 'पक्ष अनुपात',

                'no_fixed' => [
                    'label' => 'फ्री',
                ],

            ],

        ],

    ],

    'key_value' => [

        'actions' => [

            'add' => [
                'label' => 'पङ्क्ति थप्नुहोस्',
            ],

            'delete' => [
                'label' => 'पङ्क्ति मेटाउनुहोस्',
            ],

            'reorder' => [
                'label' => 'पङ्क्ति पुन क्रमबद्ध गर्नुहोस्',
            ],

        ],

        'fields' => [

            'key' => [
                'label' => 'Key',
            ],

            'value' => [
                'label' => 'Value',
            ],

        ],

    ],

    'markdown_editor' => [

        'toolbar_buttons' => [
            'attach_files' => 'फाइलहरू संलग्न गर्नुहोस्',
            'blockquote' => 'ब्लककोट',
            'bold' => 'बोल्ड',
            'bullet_list' => 'बुलेट सूची',
            'code_block' => 'कोड ब्लक',
            'heading' => 'हेडिङ',
            'italic' => 'इटालिक',
            'link' => 'लिङ्क',
            'ordered_list' => 'अंकित सूची',
            'redo' => 'पुन गर्नुहोस्',
            'strike' => 'स्ट्राइकथ्रु',
            'table' => 'तालिका',
            'undo' => 'पूर्ववत गर्नुहोस्',
        ],

    ],

    'repeater' => [

        'actions' => [

            'add' => [
                'label' => ':label मा थप्नुहोस्',
            ],

            'delete' => [
                'label' => 'मेटाउनुहोस्',
            ],

            'clone' => [
                'label' => 'क्लोन',
            ],

            'reorder' => [
                'label' => 'मुभ',
            ],

            'move_down' => [
                'label' => 'तल सार्नुहोस्',
            ],

            'move_up' => [
                'label' => 'माथि सार्नुहोस्',
            ],

            'collapse' => [
                'label' => 'संक्षिप्त गर्नुहोस्',
            ],

            'expand' => [
                'label' => 'विस्तार गर्नुहोस्',
            ],

            'collapse_all' => [
                'label' => 'सबै संक्षिप्त गर्नुहोस्',
            ],

            'expand_all' => [
                'label' => 'सबै विस्तार गर्नुहोस्',
            ],

        ],

    ],

    'rich_editor' => [

        'dialogs' => [

            'link' => [

                'actions' => [
                    'link' => 'लिङ्क गर्नुहोस्',
                    'unlink' => 'अनलिंक गर्नुहोस्',
                ],

                'label' => 'URL',

                'placeholder' => 'URL इनपुट गर्नुहोस्',

            ],

        ],

        'toolbar_buttons' => [
            'attach_files' => 'फाइलहरू संलग्न गर्नुहोस्',
            'blockquote' => 'ब्लककोट',
            'bold' => 'बोल्ड',
            'bullet_list' => 'बुलेट सूची',
            'code_block' => 'कोड ब्लक',
            'h1' => 'शीर्षक',
            'h2' => 'हेडिङ',
            'h3' => 'उपशीर्षक',
            'italic' => 'इटालिक',
            'link' => 'लिङ्क',
            'ordered_list' => 'अंकित सूची',
            'redo' => 'पुन गर्नुहोस्',
            'strike' => 'स्ट्राइकथ्रु',
            'underline' => 'अन्डरलाइन',
            'undo' => 'पूर्ववत गर्नुहोस्',
        ],

    ],

    'select' => [

        'actions' => [

            'create_option' => [

                'modal' => [

                    'heading' => 'सिर्जना गर्नुहोस्',

                    'actions' => [

                        'create' => [
                            'label' => 'सिर्जना गर्नुहोस्',
                        ],

                        'create_another' => [
                            'label' => 'बनाउनुहोस् र अर्को सिर्जना गर्नुहोस्',
                        ],

                    ],

                ],

            ],

            'edit_option' => [

                'modal' => [

                    'heading' => 'सम्पादन गर्नुहोस्',

                    'actions' => [

                        'save' => [
                            'label' => 'सुरक्षित गर्नुहोस',
                        ],

                    ],

                ],

            ],

        ],

        'boolean' => [
            'true' => 'हो',
            'false' => 'होईन',
        ],

        'loading_message' => 'लोड गर्दै...',

        'max_items_message' => ':count वस्तुहरू मात्र चयन गर्न सकिन्छ।',

        'no_search_results_message' => 'कुनै पनि विकल्प तपाईंको खोजसँग मेल खाँदैन।',

        'placeholder' => 'एक विकल्प चयन गर्नुहोस्',

        'searching_message' => 'खोज्दै...',

        'search_prompt' => 'खोज्न टाइप गर्न सुरु गर्नुहोस्...',

    ],

    'tags_input' => [
        'placeholder' => 'नयाँ ट्याग',
    ],

    'wizard' => [

        'actions' => [

            'previous_step' => [
                'label' => 'पछाडि',
            ],

            'next_step' => [
                'label' => 'अर्को',
            ],

        ],

    ],

];
