<?php

return [

    'confirmation' => 'Naozaj chcete pokračovať?',

    'actions' => [

        'cancel' => [
            'label' => 'Zrušiť',
        ],

        'confirm' => [
            'label' => 'Potvrdiť',
        ],

        'submit' => [
            'label' => 'Odoslať',
        ],

    ],

];
