<?php

return [

    'title' => 'Parolni qayta o\'rnatish',

    'heading' => 'Parolni unutdingizmi?',

    'actions' => [

        'login' => [
            'label' => 'Kirish sahifasiga qaytish',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'Elektron pochta manzili',
        ],

        'actions' => [

            'request' => [
                'label' => 'Xabar yuborish',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'Urinishlar soni juda ko\'p',
            'body' => 'Iltimos, :seconds soniyadan keyin qayta urinib ko\'ring.',
        ],

    ],

];
