<?php

namespace Filament\Resources\Pages\ListRecords;

use Filament\Resources\Components\Tab as BaseTab;

/**
 * @deprecated Use `\Filament\Resources\Components\Tab` instead.
 */
class Tab extends BaseTab {}
