<?php

return [

    'title' => 'Resetează parola',

    'heading' => 'Ai uitat parola?',

    'actions' => [

        'login' => [
            'label' => 'înapoi la autentificare',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'Email',
        ],

        'actions' => [

            'request' => [
                'label' => 'Trimite email',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'Prea multe încercări consecutive',
            'body' => 'Încearcă te rog din nou peste :seconds secunde.',
        ],

    ],

];
