<?php

return [

    'title' => 'Змінити :label',

    'breadcrumb' => 'Змінити',

    'form' => [

        'actions' => [

            'cancel' => [
                'label' => 'Скасувати',
            ],

            'save' => [
                'label' => 'Зберегти',
            ],

        ],

    ],

    'content' => [

        'tab' => [
            'label' => 'Змінити',
        ],

    ],

    'notifications' => [

        'saved' => [
            'title' => 'Збережено',
        ],

    ],

];
