<?php

return [

    'label' => 'იმპორტი :label',

    'modal' => [

        'heading' => 'იმპორტი :label',

        'form' => [

            'file' => [

                'label' => 'ფაილი',

                'placeholder' => 'ატვირთეთ CSV ფაილი',

                'rules' => [
                    'duplicate_columns' => '{0} ფაილში არ უნდა იყოს ერთზე მეტი ცარიელი სვეტი სათაურში.|{1,*} ფაილში არ უნდა იყოს დუბლირებული სვეტის სათაურები: :columns.',
                ],

            ],

            'columns' => [
                'label' => 'სვეტები',
                'placeholder' => 'აირჩიეთ სვეტი',
            ],

        ],

        'actions' => [

            'download_example' => [
                'label' => 'გადმოწერეთ მაგალითი(CSV ფაილი)',
            ],

            'import' => [
                'label' => 'იმპორტი',
            ],

        ],

    ],

    'notifications' => [

        'completed' => [

            'title' => 'იმპორტი დასრულდა',

            'actions' => [

                'download_failed_rows_csv' => [
                    'label' => 'გადმოწერეთ ინფორმაცია შეცდომით ჩანაწერის შესახებ|გადმოწერეთ ინფორმაცია შეცდომით ჩანაწერების შესახებ',
                ],

            ],

        ],

        'max_rows' => [
            'title' => 'ატვირთული CSV ფაილი ზედმეტად დიდია',
            'body' => 'თქვენ არ შეგიძლიათ ერთდროულად ერთზე მეტი ჩანაწერის იმპორტი.|თქვენ არ შეგიძლიათ ერთდროულად :count -ზე მეტი  ჩანაწერის იმპორტი.',
        ],

        'started' => [
            'title' => 'იმპორტი დაწყებულია',
            'body' => 'იმპორტი დაიწყო და 1 ჩანაწერი დამუშავდება სერვერზე.|იმპორტი დაიწყო და :count ჩანაწერი დამუშავდება სერვერზე.',
        ],

    ],

    'example_csv' => [
        'file_name' => ':importer-example',
    ],

    'failure_csv' => [
        'file_name' => 'იმპორტი-:import_id-:csv_name-შეცდომები',
        'error_header' => 'შეცდომა',
        'system_error' => 'სისტემური შეცდომა, გთხოვთ დაუკავშირდეთ მხარდაჭერის სამსახურს.',
        'column_mapping_required_for_new_record' => ':attribute სვეტი არ მიესადაგებული ფაილის სვეტს, მაგრამ ის საჭიროა ახალი ჩანაწერების შესაქმნელად.',
    ],

];
