<?php

return [

    'single' => [

        'label' => '복원',

        'modal' => [

            'heading' => ':label 복원',

            'actions' => [

                'restore' => [
                    'label' => '복원',
                ],

            ],

        ],

        'notifications' => [

            'restored' => [
                'title' => '복원 완료',
            ],

        ],

    ],

    'multiple' => [

        'label' => '선택한 항목 복원',

        'modal' => [

            'heading' => '선택한 :label 복원',

            'actions' => [

                'restore' => [
                    'label' => '복원',
                ],

            ],

        ],

        'notifications' => [

            'restored' => [
                'title' => '복원 완료',
            ],

        ],

    ],

];
