<?php

return [

    'single' => [

        'label' => 'กู้คืน',

        'modal' => [

            'heading' => 'กู้คืน :label',

            'actions' => [

                'restore' => [
                    'label' => 'กู้คืน',
                ],

            ],

        ],

        'notifications' => [

            'restored' => [
                'title' => 'กู้คืนข้อมูลเรียบร้อย',
            ],

        ],

    ],

    'multiple' => [

        'label' => 'กู้คืนที่เลือก',

        'modal' => [

            'heading' => 'กู้คืน :label ที่เลือก',

            'actions' => [

                'restore' => [
                    'label' => 'กู้คืน',
                ],

            ],

        ],

        'notifications' => [

            'restored' => [
                'title' => 'กู้คืนข้อมูลเรียบร้อย',
            ],

        ],

    ],

];
