<?php

return [

    'builder' => [

        'actions' => [

            'clone' => [
                'label' => 'همسان‌سازی',
            ],

            'add' => [
                'label' => 'افزودن به :label',
            ],

            'add_between' => [
                'label' => 'قراردادن',
            ],

            'delete' => [
                'label' => 'حذف',
            ],

            'reorder' => [
                'label' => 'جابه‌جایی',
            ],

            'move_down' => [
                'label' => 'پایین آوردن',
            ],

            'move_up' => [
                'label' => 'بالا بردن',
            ],

            'collapse' => [
                'label' => 'جمع کردن',
            ],

            'expand' => [
                'label' => 'باز کردن',
            ],

            'collapse_all' => [
                'label' => 'جمع کردن همه',
            ],

            'expand_all' => [
                'label' => 'باز کردن همه',
            ],

        ],

    ],

    'checkbox_list' => [

        'actions' => [

            'deselect_all' => [
                'label' => 'لغو انتخاب همه',
            ],

            'select_all' => [
                'label' => 'انتخاب همه',
            ],

        ],

    ],

    'file_upload' => [

        'editor' => [

            'actions' => [

                'cancel' => [
                    'label' => 'لغو',
                ],

                'drag_crop' => [
                    'label' => 'حالت کشیدن «برش»',
                ],

                'drag_move' => [
                    'label' => 'حالت کشیدن «حرکت»',
                ],

                'flip_horizontal' => [
                    'label' => 'برگردان افقی عکس',
                ],

                'flip_vertical' => [
                    'label' => 'برگردان عمودی عکس',
                ],

                'move_down' => [
                    'label' => 'به پایین بردن عکس',
                ],

                'move_left' => [
                    'label' => 'به چپ بردن عکس',
                ],

                'move_right' => [
                    'label' => 'به راست بردن عکس',
                ],

                'move_up' => [
                    'label' => 'به بالا بردن عکس',
                ],

                'reset' => [
                    'label' => 'بازنشانی',
                ],

                'rotate_left' => [
                    'label' => 'چرخاندن عکس به چپ',
                ],

                'rotate_right' => [
                    'label' => 'چرخاندن عکس به راست',
                ],

                'set_aspect_ratio' => [
                    'label' => 'تنظیم نسبت ابعاد به :ratio',
                ],

                'save' => [
                    'label' => 'ذخیره',
                ],

                'zoom_100' => [
                    'label' => 'بزرگنمایی عکس به 100%',
                ],

                'zoom_in' => [
                    'label' => 'بزرگنمایی',
                ],

                'zoom_out' => [
                    'label' => 'دورنمایی',
                ],

            ],

            'fields' => [

                'height' => [
                    'label' => 'ارتفاع',
                    'unit' => 'px',
                ],

                'rotation' => [
                    'label' => 'چرخش',
                    'unit' => 'deg',
                ],

                'width' => [
                    'label' => 'عرض',
                    'unit' => 'px',
                ],

                'x_position' => [
                    'label' => 'X',
                    'unit' => 'px',
                ],

                'y_position' => [
                    'label' => 'Y',
                    'unit' => 'px',
                ],

            ],

            'aspect_ratios' => [

                'label' => 'نسبت ابعاد',

                'no_fixed' => [
                    'label' => 'آزاد',
                ],

            ],

            'svg' => [

                'messages' => [
                    'confirmation' => 'ویرایش فایل‌های SVG توصیه نمی‌شود، زیرا می‌تواند منجر به کاهش کیفیت در هنگام مقیاس‌بندی شود.\n آیا مطمئن هستید که می‌خواهید ادامه دهید؟',
                    'disabled' => 'ویرایش فایل‌های SVG غیرفعال است زیرا می‌تواند منجر به کاهش کیفیت در هنگام مقیاس‌بندی شود.',
                ],

            ],

        ],

    ],

    'key_value' => [

        'actions' => [

            'add' => [
                'label' => 'افزودن ردیف',
            ],

            'delete' => [
                'label' => 'حذف ردیف',
            ],

            'reorder' => [
                'label' => 'بازچینش ردیف',
            ],

        ],

        'fields' => [

            'key' => [
                'label' => 'کلید',
            ],

            'value' => [
                'label' => 'مقدار',
            ],

        ],

    ],

    'markdown_editor' => [

        'toolbar_buttons' => [
            'attach_files' => 'پیوستن فایل ها',
            'blockquote' => 'نقل قول',
            'bold' => 'پررنگ',
            'bullet_list' => 'لیست نامرتب',
            'code_block' => 'بلاک کد',
            'heading' => 'عنوان',
            'italic' => 'مورب',
            'link' => 'لینک',
            'ordered_list' => 'لیست مرتب',
            'redo' => 'اَزنو',
            'strike' => 'خط زده',
            'table' => 'جدول',
            'undo' => 'واگرد',
        ],

    ],

    'radio' => [

        'boolean' => [
            'true' => 'بله',
            'false' => 'خیر',
        ],

    ],

    'repeater' => [

        'actions' => [

            'add' => [
                'label' => 'افزودن به :label',
            ],

            'add_between' => [
                'label' => 'درج بین',
            ],

            'delete' => [
                'label' => 'حذف',
            ],

            'clone' => [
                'label' => 'همسان‌سازی',
            ],

            'reorder' => [
                'label' => 'جابه‌جایی',
            ],

            'move_down' => [
                'label' => 'پایین آوردن',
            ],

            'move_up' => [
                'label' => 'بالا بردن',
            ],

            'collapse' => [
                'label' => 'جمع کردن',
            ],

            'expand' => [
                'label' => 'باز کردن',
            ],

            'collapse_all' => [
                'label' => 'جمع کردن همه',
            ],

            'expand_all' => [
                'label' => 'باز کردن همه',
            ],

        ],

    ],

    'rich_editor' => [

        'dialogs' => [

            'link' => [

                'actions' => [
                    'link' => 'لینک',
                    'unlink' => 'لغو لینک',
                ],

                'label' => 'آدرس اینترنتی',

                'placeholder' => 'یک آدرس اینترنتی وارد کنید',

            ],

        ],

        'toolbar_buttons' => [
            'attach_files' => 'پیوستن فایل ها',
            'blockquote' => 'نقل قول',
            'bold' => 'پررنگ',
            'bullet_list' => 'لیست نامرتب',
            'code_block' => 'بلوک کد',
            'h1' => 'عنوان اصلی',
            'h2' => 'عنوان فرعی',
            'h3' => 'زیرعنوان',
            'italic' => 'مورب',
            'link' => 'لینک',
            'ordered_list' => 'لیست مرتب',
            'redo' => 'جلو',
            'strike' => 'خط زده',
            'underline' => 'زیرخط',
            'undo' => 'عقب',
        ],

    ],

    'select' => [

        'actions' => [

            'create_option' => [

                'modal' => [

                    'heading' => 'ایجاد',

                    'actions' => [

                        'create' => [
                            'label' => 'ایجاد',
                        ],

                        'create_another' => [
                            'label' => 'ایجاد و ایجاد یکی دیگر',
                        ],

                    ],

                ],

            ],

            'edit_option' => [

                'modal' => [

                    'heading' => 'ویرایش',

                    'actions' => [

                        'save' => [
                            'label' => 'ذخیره',
                        ],

                    ],

                ],

            ],

        ],

        'boolean' => [
            'true' => 'بله',
            'false' => 'خیر',
        ],

        'loading_message' => 'درحال بارگذاری...',

        'max_items_message' => 'تنها :count مورد می‌تواند انتخاب شود.',

        'no_search_results_message' => 'هیچ گزینه‌ای با جستجوی شما مطابقت ندارد.',

        'placeholder' => 'یک گزینه را انتخاب کنید',

        'searching_message' => 'درحال جستجو...',

        'search_prompt' => 'برای جستجو تایپ کنید...',

    ],

    'tags_input' => [
        'placeholder' => 'تگ جدید',
    ],

    'text_input' => [

        'actions' => [

            'hide_password' => [
                'label' => 'مخفی کردن رمز',
            ],

            'show_password' => [
                'label' => 'نشان دادن رمز',
            ],

        ],

    ],

    'toggle_buttons' => [

        'boolean' => [
            'true' => 'بله',
            'false' => 'خیر',
        ],

    ],

    'wizard' => [

        'actions' => [

            'previous_step' => [
                'label' => 'قبلی',
            ],

            'next_step' => [
                'label' => 'بعدی',
            ],

        ],

    ],

];
