<?php

return [

    'label' => 'Արտահանել :label',

    'modal' => [

        'heading' => 'Արտահանել :label',

        'form' => [

            'columns' => [

                'label' => 'Սյունակներ',

                'form' => [

                    'is_enabled' => [
                        'label' => ':column միացված է',
                    ],

                    'label' => [
                        'label' => ':column պիտակ',
                    ],

                ],

            ],

        ],

        'actions' => [

            'export' => [
                'label' => 'Արտահանել',
            ],

        ],

    ],

    'notifications' => [

        'completed' => [

            'title' => 'Արտահանումն ավարտված է',

            'actions' => [

                'download_csv' => [
                    'label' => 'Ներբեռնել .csv',
                ],

                'download_xlsx' => [
                    'label' => 'Ներբեռնել .xlsx',
                ],

            ],

        ],

        'max_rows' => [
            'title' => 'Արտահանումը չափազանց մեծ է',
            'body' => 'Դուք չեք կարող միաժամանակ արտահանել ավելի քան 1 տող։|Դուք չեք կարող միաժամանակ արտահանել ավելի քան :count տող։',
        ],

        'started' => [
            'title' => 'Արտահանումը սկսվել է',
            'body' => 'Ձեր արտահանումը սկսվել է, և 1 տողը կմշակվի հետին պլանում։ Ավարտվելուց հետո դուք կստանաք ծանուցում ներբեռնման հղումով։|Ձեր արտահանումը սկսվել է, և :count տողը կմշակվի հետին պլանում։ Ավարտվելուց հետո դուք կստանաք ծանուցում ներբեռնման հղումով։',
        ],

    ],

    'file_name' => 'export-:export_id-:model',

];
