<?php

return [

    'confirmation' => 'Weet je zeker dat je dit wilt doen?',

    'actions' => [

        'cancel' => [
            'label' => 'Annuleren',
        ],

        'confirm' => [
            'label' => 'Bevestigen',
        ],

        'submit' => [
            'label' => 'Verzenden',
        ],

    ],

];
