<?php

return [

    'single' => [

        'label' => 'Сэргээх',

        'modal' => [

            'heading' => 'Сэргээх :label',

            'actions' => [

                'restore' => [
                    'label' => 'Сэргээх',
                ],

            ],

        ],

        'notifications' => [

            'restored' => [
                'title' => 'Сэргээв',
            ],

        ],

    ],

    'multiple' => [

        'label' => 'Сонгосонг сэргээх',

        'modal' => [

            'heading' => 'Сэргээх :label',

            'actions' => [

                'restore' => [
                    'label' => 'Сэргээх',
                ],

            ],

        ],

        'notifications' => [

            'restored' => [
                'title' => 'Сэргээв',
            ],

        ],

    ],

];
