<?php

return [

    'confirmation' => 'Êtes-vous sûr de vouloir faire cela ?',

    'actions' => [

        'cancel' => [
            'label' => 'Annuler',
        ],

        'confirm' => [
            'label' => 'Confirmer',
        ],

        'submit' => [
            'label' => 'Soumettre',
        ],

    ],

];
