<?php

return [

    'single' => [

        'label' => '解除关联',

        'modal' => [

            'heading' => '解除 :label 的关联',

            'actions' => [

                'dissociate' => [
                    'label' => '解除关联',
                ],

            ],

        ],

        'notifications' => [

            'dissociated' => [
                'title' => '已解除关联',
            ],

        ],

    ],

    'multiple' => [

        'label' => '解除已选项目关联',

        'modal' => [

            'heading' => '解除已选 :label 的关联',

            'actions' => [

                'dissociate' => [
                    'label' => '解除已选项目关联',
                ],

            ],

        ],

        'notifications' => [

            'dissociated' => [
                'title' => '已解除关联',
            ],

        ],

    ],

];
