<?php

return [

    'title' => 'Ponastavite svoje geslo',

    'heading' => 'Ste pozabili geslo?',

    'actions' => [

        'login' => [
            'label' => 'nazaj na prijavo',
        ],

    ],

    'form' => [

        'email' => [
            'label' => 'E-poštni naslov',
        ],

        'actions' => [

            'request' => [
                'label' => 'Pošlji e-pošto',
            ],

        ],

    ],

    'notifications' => [

        'throttled' => [
            'title' => 'Preveč zahtevkov',
            'body' => 'Prosimo, poskusite znova čez :seconds sekund.',
        ],

    ],

];
