<?php

return [

    'direction' => 'ltr',

    'actions' => [

        'logout' => [
            'label' => 'সাইন আউট',
        ],

        'open_database_notifications' => [
            'label' => 'বিজ্ঞপ্তি খুলুন',
        ],

        'open_user_menu' => [
            'label' => 'ব্যবহার সূচী',
        ],

        'theme_switcher' => [

            'dark' => [
                'label' => 'ডার্ক মোড',
            ],

            'light' => [
                'label' => 'লাইট মোড',
            ],

        ],

    ],

];
