<?php

return [

    'title' => 'ផ្ទៀងផ្ទាត់អាសយដ្ឋានអ៊ីមែលរបស់អ្នក',

    'heading' => 'ផ្ទៀងផ្ទាត់អាសយដ្ឋានអ៊ីមែលរបស់អ្នក',

    'actions' => [

        'resend_notification' => [
            'label' => 'ផ្ញើឡើងវិញ',
        ],

    ],

    'messages' => [
        'notification_not_received' => 'មិនបានទទួលអ៊ីមែលដែលយើងផ្ញើទេ?',
        'notification_sent' => 'យើងបានផ្ញើអ៊ីមែលទៅ​​ :email ដែលមានការណែនាំអំពីរបៀបផ្ទៀងផ្ទាត់អាសយដ្ឋានអ៊ីមែលរបស់អ្នក។.',
    ],

    'notifications' => [

        'notification_resent' => [
            'title' => 'យើងបានផ្ញើអ៊ីមែលឡើងវិញ។.',
        ],

        'notification_resend_throttled' => [
            'title' => 'ការព្យាយាមផ្ញើឡើងវិញច្រើនពេក',
            'body' => 'សូមព្យាយាមម្តងទៀតក្នុងរយៈពេល :seconds វិនាទី។.',
        ],

    ],

];
