<?php

return [

    'direction' => 'ltr',

    'actions' => [

        'billing' => [
            'label' => 'Administrer abonnementer',
        ],

        'logout' => [
            'label' => 'Log ud',
        ],

        'open_database_notifications' => [
            'label' => 'Åbn notifikationer',
        ],

        'open_user_menu' => [
            'label' => 'Brugermenu',
        ],

        'sidebar' => [

            'collapse' => [
                'label' => 'Skjul sidebjælken',
            ],

            'expand' => [
                'label' => 'Udvid sidebjælken',
            ],

        ],

        'theme_switcher' => [

            'dark' => [
                'label' => 'Skift til mørk tilstand',
            ],

            'light' => [
                'label' => 'Skift til lys tilstand',
            ],

            'system' => [
                'label' => 'Skift til systemtilstand',
            ],

        ],

    ],

];
