<?php

return [

    'entries' => [

        'text' => [

            'actions' => [
                'collapse_list' => 'Скрыть :count',
                'expand_list' => 'Показать еще :count',
            ],

            'more_list_items' => 'и еще :count',

        ],

        'key_value' => [

            'columns' => [

                'key' => [
                    'label' => 'Ключ',
                ],

                'value' => [
                    'label' => 'Значение',
                ],

            ],

            'placeholder' => 'Нет записей',

        ],

    ],

];
