<?php

return [

    'builder' => [

        'actions' => [

            'add' => [
                'label' => ':label में जोड़ें',
            ],

            'add_between' => [
                'label' => 'के बीच जोड़ें',
            ],

            'delete' => [
                'label' => 'हटाएँ',
            ],

            'move_down' => [
                'label' => 'नीचे करे',
            ],

            'move_up' => [
                'label' => 'ऊपर करे',
            ],

        ],

    ],

    'key_value' => [

        'actions' => [

            'add' => [
                'label' => 'पंक्ति जोड़ें',
            ],

            'delete' => [
                'label' => 'पंक्ति हटाएँ',
            ],

        ],

        'fields' => [

            'key' => [
                'label' => 'कुंजी',
            ],

            'value' => [
                'label' => 'मान',
            ],

        ],

    ],

    'markdown_editor' => [

        'toolbar_buttons' => [
            'attach_files' => 'फ़ाइलें जोड़ें',
            'bold' => 'स्पष्ट',
            'bullet_list' => 'बुलॅट सूची',
            'code_block' => 'कोड ब्लॉक',
            'edit' => 'संपादन करे',
            'italic' => 'तिरछा',
            'link' => 'लिंक',
            'ordered_list' => 'अंकीय सूची',
            'preview' => 'पूर्वावलोकन',
            'strike' => 'शद्ब कांटे',
        ],

    ],

    'repeater' => [

        'actions' => [

            'add' => [
                'label' => ':label में जोड़ें',
            ],

            'delete' => [
                'label' => 'हटाएँ',
            ],

            'move_down' => [
                'label' => 'नीचे करे',
            ],

            'move_up' => [
                'label' => 'ऊपर करे',
            ],

        ],

    ],

    'rich_editor' => [

        'dialogs' => [

            'link' => [

                'actions' => [
                    'link' => 'लिंक',
                    'unlink' => 'अनलिंक',
                ],

                'label' => 'यूआरएल',

                'placeholder' => 'यूआरएल(URL) डाले',

            ],

        ],

        'toolbar_buttons' => [
            'attach_files' => 'फ़ाइलें जोड़ें',
            'blockquote' => 'ब्लॉककोट',
            'bold' => 'स्पष्ट',
            'bullet_list' => 'बुलॅट सूची',
            'code_block' => 'कोड ब्लॉक',
            'h1' => 'शीर्षक',
            'h2' => 'शीर्षक',
            'h3' => 'उपशीर्षक',
            'italic' => 'तिरछा',
            'link' => 'लिंक',
            'ordered_list' => 'अंकीय सूची',
            'redo' => 'दोहराएँ',
            'strike' => 'शद्ब कांटे',
            'undo' => 'पूर्ववत्',
        ],

    ],

    'select' => [
        'no_search_results_message' => 'आपकी खोज से मेल खाने वाला कोई विकल्प नहीं मिला',
        'placeholder' => 'किसी विकल्प का चयन करें',
        'search_prompt' => 'खोज करने के लिए लिखना प्रारंभ करें...',
    ],

    'tags_input' => [
        'placeholder' => 'नया टैग',
    ],

];
